function sym_con

% SYM_CON Show the help for the functions in this toolbox.

% This file is automatically generated.  Matthew Simoneau, 09-04-98
% Copyright (c) 1984-98 by The MathWorks, Inc. All Rights Reserved
% $Revision: 1.10 $ $Date: 1998/10/16 23:19:43 $

helpwin('sym_con/Contents');

function Contents
%MATLAB Tour Partial Function Help:  sym_con
%
%Double click on any function for more information
%
%  Symbolic Math Toolbox.
%  Version 2.1    (R11)  11-Sep-1998
% 
%  New Features.
%    Readme      - Overview of the new features in/changes made to
%                  the Symbolic and Extended Symbolic Math Toolboxes.
% 
%  Calculus.
%    diff        - Differentiate.
%    int         - Integrate.
%    limit       - Limit.
%    taylor      - Taylor series.
%    jacobian    - Jacobian matrix.
%    symsum      - Summation of series. 
% 
%  Linear Algebra.
%    diag        - Create or extract diagonals.
%    triu        - Upper triangle.
%    tril        - Lower triangle.
%    inv         - Matrix inverse.
%    det         - Determinant.
%    rank        - Rank.
%    rref        - Reduced row echelon form.
%    null        - Basis for null space.
%    colspace    - Basis for column space.
%    eig         - Eigenvalues and eigenvectors.
%    svd         - Singular values and singular vectors.
%    jordan      - Jordan canonical (normal) form.
%    poly        - Characteristic polynomial.
%    expm        - Matrix exponential.
% 
%  Simplification.
%    simplify    - Simplify.
%    expand      - Expand.
%    factor      - Factor.
%    collect     - Collect.
%    simple      - Search for shortest form.
%    numden      - Numerator and denominator.
%    horner      - Nested polynomial representation.
%    subexpr     - Rewrite in terms of subexpressions.
%    subs        - Symbolic substitution.
% 
%  Solution of Equations.
%    solve       - Symbolic solution of algebraic equations.
%    dsolve      - Symbolic solution of differential equations.
%    finverse    - Functional inverse.
%    compose     - Functional composition.
% 
%  Variable Precision Arithmetic.
%    vpa         - Variable precision arithmetic.
%    digits      - Set variable precision accuracy.
% 
%  Integral Transforms.
%    fourier     - Fourier transform.
%    laplace     - Laplace transform.
%    ztrans      - Z transform.
%    ifourier    - Inverse Fourier transform.
%    ilaplace    - Inverse Laplace transform.
%    iztrans     - Inverse Z transform.
% 
%  Conversions.
%    double      - Convert symbolic matrix to double.
%    poly2sym    - Coefficient vector to symbolic polynomial.
%    sym2poly    - Symbolic polynomial to coefficient vector.
%    char        - Convert sym object to string.
% 
%  Basic Operations.
%    sym         - Create symbolic object.
%    syms        - Short-cut for constructing symbolic objects.
%    findsym     - Determine symbolic variables.
%    pretty      - Pretty print a symbolic expression.
%    latex       - LaTeX representation of a symbolic expression.
%    ccode       - C code representation of a symbolic expression.
%    fortran     - FORTRAN representation of a symbolic expression.
% 
%  Special Functions.
%    sinint      - Sine integral.
%    cosint      - Cosine integral.
%    zeta        - Riemann zeta function.
%    lambertw    - Lambert W function.
% 
%  String handling utilities.
%    isvarname   - Check for a valid variable name.
%    vectorize   - Vectorize a symbolic expression.
% 
%  Pedagogical and Graphical Applications.
%    rsums       - Riemann sums.
%    ezcontour   - Easy to use contour plotter.
%    ezcontourf  - Easy to use filled contour plotter.
%    ezmesh      - Easy to use mesh (surface) plotter.
%    ezmeshc     - Easy to use combined mesh/contour plotter.
%    ezplot      - Easy to use function, implicit, and parametric curve plotter.
%    ezplot3     - Easy to use spatial curve plotter.
%    ezpolar     - Easy to use polar coordinates plotter.
%    ezsurf      - Easy to use surface plotter.
%    ezsurfc     - Easy to use combined surface/contour plotter.
%    funtool     - Function calculator.
%    taylortool  - Taylor series calculator.
% 
%  Demonstrations.
%    symintro    - Introduction to the Symbolic Toolbox.
%    symcalcdemo - Calculus demonstration.
%    symlindemo  - Demonstrate symbolic linear algebra.
%    symvpademo  - Demonstrate variable precision arithmetic
%    symrotdemo  - Study plane rotations.
%    symeqndemo  - Demonstrate symbolic equation solving.
% 
%  Access to Maple. (Not available with Student Edition.)
%    maple       - Access Maple kernel.
%    mfun        - Numeric evaluation of Maple functions.
%    mfunlist    - List of functions for MFUN.
%    mhelp       - Maple help.
%    procread    - Install a Maple procedure. (Requires Extended Toolbox.)
%

function Readme
%MATLAB Tour Partial Function Help:  sym_con
%
%  Release Notes
%  Version 2.1  (R11)
%  Symbolic Math Toolbox
%  Extended Symbolic Toolbox
%  11-Sep-1998
% 
%  V E R S I O N   2.1
% 
%  Version 2.1 of the Symbolic Math Toolboxes contains two significant new features:
%  The incorporation of the Maple V, Release 5 (MathEdge 2) OEM kernel and
%  a series of plotting commands that enable the user to graph symbolic expressions
%  that represent planar and spatial curves, polar coordinates, surfaces, and
%  contours.
% 
%  In particular, EZPLOT graphs curves of the form y = f(x), f(x,y) = 0
%  (i.e., implicit functions), and x = x(t), y = y(t) (parametric planar curves).
%  The utility EZPLOT3 graphs x = x(t), y = t(t), z = z(t) (parametric spatial curves)
%  while EZPOLAR plots r = f(theta) in polar coordinates.  Finally, EZSURF, EZSURFC,
%  EZMESH, and EZMESHC graph surfaces/combined surface-contour plots on symbolic
%  expressions of the form z = f(x,y); EZCONTOUR gives a contour graph of z = f(x,y).
% 
%  Three new additional functions have been added:  HYPERGEOM, TEXLABEL, and
%  TAYLORTOOL.  HYPERGEOM returns Gauss' hypergeometric functions of various
%  orders; TEXLABEL converts a symbolic expression into its equivalent TeX form
%  to be used in combination with title, xlabel, ylabel, and/or zlabel.  This
%  provides titles and labels that resemble mathematical typesetting.
%  TAYLORTOOL is a pedagogical tool that enables the user to visualize the
%  convergence of a Taylor series to a given input function.
% 
%  DSOLVE has been made more robust and returns solutions to a wider variety
%  of differential equation (especially nonlinear ODEs).  A new option to the
%  SYMS function has been provided:
%  syms a k positive
%  creates positive real variables a and k.
% 
%  The new Maple V, Release 5 kernel corrects several errors in the computation
%  of symbolic eigenvalues and differential equations as well as correcting the
%  memory management problems of Maple V, Release 4.  
% 
%  Many bug fixes and internal architectural changes to the M-files have been
%  effected to increase ease and robustness of use.
% 
%  V E R S I O N   2.0.1
% 
%  Version 2.0.1 of the Symbolic Math Toolboxes contains a new and more robust
%  SUBS function.  More specifically, a complete re-write of sym/SUBS.M, which
%  is the link between symbolic expressions and numeric expressions from within
%  the Symbolic Math Toolbox, has been added. The new sym/SUBS.M will handle all
%  substitutions (string, double, Maple, and multiple substitutions) available
%  in the Toolbox.  While the syntax for SUBS remains the same (as in Version 1
%  and Version 2.0), a change in output occurs for substitutions of class DOUBLE.
%  For example, subs(x^2,x,2.1) now returns 4.4100,  In Version 2.0, 
%  subs(x^2,x,2.1) returns 441/100. Similarly, the V 2.0.1 subs(x/y,{x,y},{2,3})
%  returns 0.6667, whereas the V 2.0 subs(x/y,{x,y},{2,3}) returns 2/3. 
% 
%     Moreover, several bugs that affected formatting, consistency of use, 
%  stability, and error handling have been fixed.  In particular, changes to
%  MAPLE.M and MAPLEINIT.M were made to eliminate Maple/MATLAB string
%  incompatibilities.
% 
%    The sym/COLON.M operator was altered to make it consistent with MATLAB.
%  The V 2.0 command sym(2):0:4 returns 2 + NaN while the new V 2.0.1 command
%  returns [ empty sym ].
% 
%    Both sym/DOUBLE.M and sym/EVAL.M were altered to permit evaluation of
%  symbolic matrices when floating point variables are in the workspace. The
%  V 2.0 commands syms x; A = A = [cos(x), sin(x);-sin(x),cos(x)]; x = pi/2;
%  eval(A) return an error.  In V 2.0.1, these commands now return the class
%  DOUBLE matrix
%      0     1
%     -1     0
% 
%    The files sym/DISP.M and sym/DISPLAY.M were changed to permit the
%  compact option in FORMAT.
% 
%    Finally, the integral transforms sym/FOURIER.M, IFOURIER.M, ILAPLACE.M,
%  IZTRANS.M, LAPLACE.M, and ZTRANS.M were reworked so that the correct
%  default variable would be selected.  That is, in V 2.0, the commands
%  syms s w t a; f = cos(w*t)*exp(-a*t); laplace(f) return exp(-a*t)*s/(s^2+t^2)
%  and laplace(f,t,s) returns (s+a)/((s+a)^2+w^2).  Now, in V 2.0.1, both
%  laplace(f) and laplace(f,t,s) return (s+a)/((s+a)^2+w^2).  Similar comments
%  hold for FOURIER, IFOURIER, etc.
% 
%  V E R S I O N   2.0
% 
%  Compatibility with Earlier Versions
%  
%  The documentation for Version 1 of the Symbolic Math Toolboxes
%  anticipated the changes envisioned for future versions:
%  
%    "These first versions of the Symbolic Math Toolboxes are designed to
%    work with version 4.0 or 4.1 of MATLAB and version V, release 2
%    of Maple.  The goal has been to provide access to most of Maple with 
%    a language syntax that is familiar to MATLAB users.  This has been
%    done without modifying either of the two underlying systems.
%    
%    However, it is not possible to provide completely seamless integration
%    without modifying MATLAB.  For example, if f and g are strings
%    representing symbolic expressions, we would prefer to use the notation
%    f+g for their sum, instead of symadd(f,g).  But f+g attempts to add
%    the individual characters in the two strings, rather than concatenate
%    them with a plus sign in between.  Similarly, if A is a matrix whose
%    elements are symbolic expressions, we would prefer to use A(i,j)
%    to access a individual expression, instead of sym(A,i,j).  But if A is
%    a matrix of strings, then A(i,j) is a single character, not a complete
%    expression.
%    
%    We intend to develop further versions of these toolboxes, to be used
%    with future versions of MATLAB and Maple.  As we do so, we will be
%    able to provide closer integration and better syntax.  In particular,
%    we expect that many of the functions whose names now involve "sym"
%    will eventually be replaced by more direct use of underlying MATLAB
%    notation."
%   
%  Version 2 of the Symbolic Math Toolboxes makes extensive use of the
%  new MATLAB object capabilities and is intended to work with a newer
%  release, number 4, of Maple, version V.  Some degree of backward
%  compatibility with Version 1 of the Toolbox is available, but complete
%  compatibility is not possible.
%  
%  The following functions continue to be available, but their usage
%  is considered obsolete.
%  
%      determ      - Symbolic matrix determinant.
%      linsolve    - Solve simultaneous linear equations.
%      eigensys    - Symbolic eigenvalues and eigenvectors.
%      singvals    - Symbolic singular values and singular vectors.
%      numeric     - Convert symbolic matrix to numeric form.
%      symop       - Symbolic operations.
%      symadd      - Add symbolic expressions.
%      symsub      - Subtract symbolic expressions.
%      symmul      - Multiply symbolic expressions.
%      symdiv      - Divide symbolic expressions.
%      sympow      - Power of symbolic expression.
%      eval        - Evaluate a symbolic expression.
%  
%  These functions accept both strings and symbolic objects as input arguments
%  and produce symbolic objects as results.  Most of the functions now also 
%  have counterparts with overloaded MATLAB operators or function names.
%  
%  For example, the version 1 statements
%  
%      f = '1/(5+4*cos(x))'
%      g = int(int(diff(f,2)))
%      e = symsub(f,g)
%      simple(e)
%  
%  continue to work with version 2.  With version 1, all three variables,
%  f, g and e, are strings; with version 2, f is a string, but g and e are
%  symbolic objects.  With version 2, the preferred approach is
%  
%      syms x
%      f = 1/(5+4*cos(x))
%      g = int(int(diff(f,2)))
%      e = f - g
%      simple(e)
%  
%  The version 1 statements
%   
%      H = sym(hilb(3))
%      I = sym(eye(3))
%      X = linsolve(H,I)
%      t = sym(0)
%      for j = 1:3
%         t = symadd(t,sym(X,j,j))
%      end
%      t
%   
%  continue to work with version 2.  With version 2, the preferred
%  approach is
%  
%  
%      H = sym(hilb(3))
%      I = eye(3)
%      X = H\I
%      t = sum(diag(X))
%  
%  The version 1 statement
%  
%      M = sym(3,3,'1/(i+j-t)')
%  
%  uses the sym function in a way that is no longer available with version 2.
%  The example must be changed to something like
%  
%      syms t
%      [J,I] = meshgrid(1:3)
%      M = 1./(I+J-t)
%  
%  The version 1 usage of diff, int, solve and dsolve with string arguments
%  continues to be available with version 2.  With version 2, the results
%  are symbolic objects instead of strings.  For some computations, the
%  new release of Maple produces results in a different format.  
%  
%  For example, with version 1, the statement
%  
%      [x,y] = solve('x^2 + 2*x*y + y^2 = 4', 'x^3 + 4*y^3 = 1')
%  
%  produces
%  
%      x =
%      [   -RootOf(_Z^3-2*_Z^2-4*_Z-3)-2]
%      [-RootOf(3*_Z^3+6*_Z^2-12*_Z+7)+2]
%   
%      y =
%      [   RootOf(_Z^3-2*_Z^2-4*_Z-3)]
%      [RootOf(3*_Z^3+6*_Z^2-12*_Z+7)]
%  
%  The same statement works in version 2, but produces results with the
%  "RootOf" expressions expanded to exhibit the multiple solutions.

function diff
%MATLAB Tour Partial Function Help:  sym_con
%
% DIFF Difference and approximate derivative.
%    DIFF(X), for a vector X, is [X(2)-X(1)  X(3)-X(2) ... X(n)-X(n-1)].
%    DIFF(X), for a matrix X, is the matrix of column differences,
%       [X(2:n,:) - X(1:n-1,:)].
%    DIFF(X), for an N-D array X, is the difference along the first
%       non-singleton dimension of X.
%    DIFF(X,N) is the N-th order difference along the first non-singleton 
%       dimension (denote it by DIM). If N >= size(X,DIM), DIFF takes 
%       successive differences along the next non-singleton dimension.
%    DIFF(X,N,DIM) is the Nth difference function along dimension DIM. 
%       If N >= size(X,DIM), DIFF returns an empty array.
% 
%    Examples:
%       h = .001; x = 0:h:pi;
%       diff(sin(x.^2))/h is an approximation to 2*cos(x.^2).*x
%       diff((1:10).^2) is 3:2:19
% 
%       If X = [3 7 5
%               0 9 2]
%       then diff(X,1,1) is [-3 2 -3], diff(X,1,2) is [4 -2
%                                                      9 -7],
%       diff(X,2,2) is the 2nd order difference along the dimension 2, and
%       diff(X,3,2) is the empty matrix.
% 
%    

function int
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for char/int.m ---
%
% INT    Alternative entry to the symbolic integration function.
%    INT(F,...) is the same as int(sym(F),...).
%    

function limit
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/limit.m ---
%
% LIMIT    Limit of an expression.
%    LIMIT(F,x,a) takes the limit of the symbolic expression F as x -> a.
%    LIMIT(F,a) uses findsym(F) as the independent variable.
%    LIMIT(F) uses a = 0 as the limit point.
%    LIMIT(F,x,a,'right') or LIMIT(F,x,a,'left') specify the direction
%    of a one-sided limit.
% 
%    Examples:
%      syms x a t h;
% 
%      limit(sin(x)/x)                 returns   1
%      limit((x-2)/(x^2-4),2)          returns   1/4
%      limit((1+2*t/x)^(3*x),x,inf)    returns   exp(6*t)
%      limit(1/x,x,0,'right')          returns   inf
%      limit(1/x,x,0,'left')           returns   -inf
%      limit((sin(x+h)-sin(x))/h,h,0)  returns   cos(x)
%      v = [(1 + a/x)^x, exp(-x)];
%      limit(v,x,inf,'left')           returns   [exp(a),  0]

function taylor
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/taylor.m ---
%
% TAYLOR Taylor series expansion.
%    TAYLOR(f) is the fifth order Maclaurin polynomial approximation to f.
%    Three additional parameters can be specified, in almost any order.
%    TAYLOR(f,n) is the (n-1)-st order Maclaurin polynomial.
%    TAYLOR(f,a) is the Taylor polynomial approximation about point a.
%    TAYLOR(f,x) uses the independent variable x instead of FINDSYM(f).
% 
%    Examples:
%       taylor(exp(-x))   returns
%          1-x+1/2*x^2-1/6*x^3+1/24*x^4-1/120*x^5
%       taylor(log(x),6,1)   returns
%          x-1-1/2*(x-1)^2+1/3*(x-1)^3-1/4*(x-1)^4+1/5*(x-1)^5
%       taylor(sin(x),pi/2,6)   returns
%          1-1/2*(x-1/2*pi)^2+1/24*(x-1/2*pi)^4
%       taylor(x^t,3,t)   returns
%          1+log(x)*t+1/2*log(x)^2*t^2
% 
%    

function jacobian
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/jacobian.m ---
%
% JACOBIAN Jacobian matrix.
%    JACOBIAN(f,v) computes the Jacobian of the scalar or vector f 
%    with respect to the vector v. The (i,j)-th entry of the result
%    is df(i)/dv(j). Note that when f is scalar, the Jacobian of f
%    is the gradient of f. Also, note that scalar v is allowed, 
%    although this is just DIFF(f,v).
% 
%    Example:
%        jacobian([x*y*z; y; x+z],[x y z])
%        jacobian(u*exp(v),[u;v])
% 
%    

function symsum
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/symsum.m ---
%
% SYMSUM Symbolic summation.
%    SYMSUM(S) is the indefinite summation of S with respect to the
%    symbolic variable determined by FINDSYM.
%    SYMSUM(S,v) is the indefinite summation with respect to v.
%    SYMSUM(S,a,b) and SYMSUM(S,v,a,b) are the definite summation from a to b.
% 
%    Examples:
%       simple(symsum(k))             1/2*k*(k-1)
%       simple(symsum(k,0,n-1))       1/2*n*(n-1)
%       simple(symsum(k,0,n))         1/2*n*(n+1)
%       simple(symsum(k^2,0,n))       1/6*n*(n+1)*(2*n+1)
%       symsum(k^2,0,10)              385
%       symsum(k^2,11,10)             0
%       symsum(1/k^2)                 -Psi(1,k)
%       symsum(1/k^2,1,Inf)           1/6*pi^2
% 
%    

function diag
%MATLAB Tour Partial Function Help:  sym_con
%
% DIAG Diagonal matrices and diagonals of a matrix.
%    DIAG(V,K) when V is a vector with N components is a square matrix
%    of order N+ABS(K) with the elements of V on the K-th diagonal. K = 0
%    is the main diagonal, K > 0 is above the main diagonal and K < 0
%    is below the main diagonal. 
% 
%    DIAG(V) is the same as DIAG(V,0) and puts V on the main diagonal.
% 
%    DIAG(X,K) when X is a matrix is a column vector formed from
%    the elements of the K-th diagonal of X.
% 
%    DIAG(X) is the main diagonal of X. DIAG(DIAG(X)) is a diagonal matrix.
% 
%    Example
%       m = 5;
%       diag(-m:m) + diag(ones(2*m,1),1) + diag(ones(2*m,1),-1)
%    produces a tridiagonal matrix of order 2*m+1.
% 
%    

function triu
%MATLAB Tour Partial Function Help:  sym_con
%
% TRIU Extract upper triangular part.
%    TRIU(X) is the upper triangular part of X.
%    TRIU(X,K) is the elements on and above the K-th diagonal of
%    X.  K = 0 is the main diagonal, K > 0 is above the main
%    diagonal and K < 0 is below the main diagonal.
% 
%    

function tril
%MATLAB Tour Partial Function Help:  sym_con
%
% TRIL Extract lower triangular part.
%    TRIL(X) is the lower triangular part of X.
%    TRIL(X,K) is the elements on and below the K-th diagonal
%    of X .  K = 0 is the main diagonal, K > 0 is above the
%    main diagonal and K < 0 is below the main diagonal.
% 
%    

function inv
%MATLAB Tour Partial Function Help:  sym_con
%
% INV    Matrix inverse.
%    INV(X) is the inverse of the square matrix X.
%    A warning message is printed if X is badly scaled or
%    nearly singular.
% 
%    

function det
%MATLAB Tour Partial Function Help:  sym_con
%
% DET    Determinant.
%    DET(X) is the determinant of the square matrix X.
% 
%    Use COND instead of DET to test for matrix singularity.
% 
%    

function rank
%MATLAB Tour Partial Function Help:  sym_con
%
% RANK   Matrix rank.
%    RANK(A) provides an estimate of the number of linearly
%    independent rows or columns of a matrix A.
%    RANK(A,tol) is the number of singular values of A
%    that are larger than tol.
%    RANK(A) uses the default tol = max(size(A)) * norm(A) * eps.
%
% Overloaded methods
%    help sym/rank.m
%    help rptcp/rank.m

function rref
%MATLAB Tour Partial Function Help:  sym_con
%
% RREF   Reduced row echelon form.
%    R = RREF(A) produces the reduced row echelon form of A.
% 
%    [R,jb] = RREF(A) also returns a vector, jb, so that:
%        r = length(jb) is this algorithm's idea of the rank of A,
%        x(jb) are the bound variables in a linear system, Ax = b,
%        A(:,jb) is a basis for the range of A,
%        R(1:r,jb) is the r-by-r identity matrix.
% 
%    [R,jb] = RREF(A,TOL) uses the given tolerance in the rank tests.
% 
%    Roundoff errors may cause this algorithm to compute a different
%    value for the rank than RANK, ORTH and NULL.
% 
%    

function null
%MATLAB Tour Partial Function Help:  sym_con
%
% NULL   Null space.
%    Z = NULL(A) is an orthonormal basis for the null space of A obtained
%    from the singular value decomposition.  That is,  A*Z has negligible
%    elements, size(Z,2) is the nullity of A, and Z'*Z = I.
% 
%    Z = NULL(A,'r') is a "rational" basis for the null space obtained
%    from the reduced row echelon form.  A*Z is zero, size(Z,2) is an
%    estimate for the nullity of A, and, if A is a small matrix with 
%    integer elements, the elements of R are ratios of small integers.  
% 
%    The orthonormal basis is preferable numerically, while the rational
%    basis may be preferable pedagogically.
% 
%    Example:
% 
%        A =
% 
%            1     2     3
%            1     2     3
%            1     2     3
% 
%       null(A) = 
% 
%          -0.1690   -0.9487
%           0.8452    0.0000
%          -0.5071    0.3162
% 
%       null(A,'r') = 
% 
%           -2    -3
%            1     0
%            0     1
% 
%    

function colspace
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/colspace.m ---
%
% COLSPACE Basis for column space.
%    The columns of B = COLSPACE(A) form a basis for the column space of A.
%    SIZE(B,2) is the rank of A.
% 
%    Example:
% 
%      colspace(sym(magic(4))) is
% 
%        [  0,  1,  0]
%        [  0,  0,  1]
%        [  1,  0,  0]
%        [ -3,  1,  3]
% 
%    

function eig
%MATLAB Tour Partial Function Help:  sym_con
%
% EIG    Eigenvalues and eigenvectors.
%    E = EIG(X) is a vector containing the eigenvalues of a square 
%    matrix X.
% 
%    [V,D] = EIG(X) produces a diagonal matrix D of eigenvalues and a
%    full matrix V whose columns are the corresponding eigenvectors so
%    that X*V = V*D.
%  
%    [V,D] = EIG(X,'nobalance') performs the computation with balancing
%    disabled, which sometimes gives more accurate results for certain
%    problems with unusual scaling.
%  
%    E = EIG(A,B) is a vector containing the generalized eigenvalues
%    of square matrices A and B.
% 
%    [V,D] = EIG(A,B) produces a diagonal matrix D of generalized
%    eigenvalues and a full matrix V whose columns are the
%    corresponding eigenvectors so that A*V = B*V*D.
% 
%    

function svd
%MATLAB Tour Partial Function Help:  sym_con
%
% SVD    Singular value decomposition.
%    [U,S,V] = SVD(X) produces a diagonal matrix S, of the same 
%    dimension as X and with nonnegative diagonal elements in
%    decreasing order, and unitary matrices U and V so that
%    X = U*S*V'.
% 
%    S = SVD(X) returns a vector containing the singular values.
% 
%    [U,S,V] = SVD(X,0) produces the "economy size"
%    decomposition. If X is m-by-n with m > n, then only the
%    first n columns of U are computed and S is n-by-n.
% 
%    

function jordan
%MATLAB Tour Partial Function Help:  sym_con
%
% JORDAN Jordan Canonical Form.
%    JORDAN(A) computes the Jordan Canonical/Normal Form of the matrix A.
%    The matrix must be known exactly, so its elements must be integers
%    or ratios of small integers.  Any errors in the input matrix may
%    completely change its JCF.
% 
%    [V,J] = JORDAN(A) also computes the similarity transformation, V, so
%    that V\A*V = J.  The columns of V are the generalized eigenvectors.
% 
%    Example:
%       A = gallery(5);
%       [V,J] = jordan(A)
% 
%    

function poly
%MATLAB Tour Partial Function Help:  sym_con
%
% POLY Convert roots to polynomial.
%    POLY(A), when A is an N by N matrix, is a row vector with
%    N+1 elements which are the coefficients of the
%    characteristic polynomial, DET(lambda*EYE(SIZE(A)) - A) .
% 
%    POLY(V), when V is a vector, is a vector whose elements are
%    the coefficients of the polynomial whose roots are the
%    elements of V . For vectors, ROOTS and POLY are inverse
%    functions of each other, up to ordering, scaling, and
%    roundoff error.
% 
%    ROOTS(POLY(1:20)) generates Wilkinson's famous example.
% 
%    

function expm
%MATLAB Tour Partial Function Help:  sym_con
%
% EXPM   Matrix exponential.
%    EXPM(X) is the matrix exponential of X.  EXPM is computed using
%    a scaling and squaring algorithm with a Pade approximation.
% 
%    Although it is not computed this way, if X has a full set
%    of eigenvectors V with corresponding eigenvalues D, then
%    [V,D] = EIG(X) and EXPM(X) = V*diag(exp(diag(D)))/V.
% 
%    EXPM1, EXPM2 and EXPM3 are alternative methods.
% 
%    EXP(X) (that's without the M) does it element-by-element.
% 
%    

function simplify
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/simplify.m ---
%
% SIMPLIFY Symbolic simplification.
%    SIMPLIFY(S) simplifies each element of the symbolic matrix S.
% 
%    Examples: 
%       simplify(sin(x)^2 + cos(x)^2) is 1 .
%       simplify(exp(c*log(sqrt(alpha+beta))))
% 
%    

function expand
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/expand.m ---
%
% EXPAND Symbolic expansion.
%    EXPAND(S) writes each element of a symbolic expression S as a
%    product of its factors.  EXPAND is most often used on polynomials,
%    but also expands trigonometric, exponential and logarithmic functions.
% 
%    Examples:
%       v = [exp(x + y) log(x^2/y)]
%       expand((x+1)^3)   returns  x^3+3*x^2+3*x+1
%       expand(sin(x+y))  returns  sin(x)*cos(y)+cos(x)*sin(y)
%       expand(v)         returns  [exp(x)*exp(y), 2*log(x)-log(y)]
% 
%    

function factor
%MATLAB Tour Partial Function Help:  sym_con
%
% FACTOR Prime factors.
%    FACTOR(N) returns a vector containing the prime factors of N.
% 
%    

function collect
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/collect.m ---
%
% COLLECT Collect coefficients.
%    COLLECT(S,v) regards each element of the symbolic matrix S as a
%    polynomial in v and rewrites S in terms of the powers of v.
%    COLLECT(S) uses the default variable determined by FINDSYM.
% 
%    Examples:
%       collect(x^2*y + y*x - x^2 - 2*x)   returns   (y-1)*x^2+(y-2)*x
% 
%       f = -1/4*x*exp(-2*x)+3/16*exp(-2*x)
%       collect(f,exp(-2*x))   returns   (-1/4*x+3/16)*exp(-2*x)
% 
%    

function simple
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/simple.m ---
%
% SIMPLE Search for simplest form of a symbolic expression or matrix.
%    SIMPLE(S) tries several different algebraic simplifications of
%    S, displays any which shorten the length of S's representation,
%    and returns the shortest. S is a SYM. If S is a matrix, the result
%    represents the shortest representation of the entire matrix, which is 
%    not necessarily the shortest representation of each individual element.
% 
%    [R,HOW] = SIMPLE(S) does not display intermediate simplifications,
%    but returns the shortest found, as well as a string describing
%    the particular simplification. R is a SYM. HOW is a string.
% 
%    Examples:
% 
%       S                          R                  How
% 
%       cos(x)^2+sin(x)^2          1                  combine(trig)
%       2*cos(x)^2-sin(x)^2        3*cos(x)^2-1       simplify
%       cos(x)^2-sin(x)^2          cos(2*x)           combine(trig)
%       cos(x)+(-sin(x)^2)^(1/2)   cos(x)+i*sin(x)    radsimp
%       cos(x)+i*sin(x)            exp(i*x)           convert(exp)
%       (x+1)*x*(x-1)              x^3-x              collect(x)
%       x^3+3*x^2+3*x+1            (x+1)^3            factor
%       cos(3*acos(x))             4*x^3-3*x          expand
% 
%       syms x y positive
%       log(x) + log(y)            log(x*y)           combine
% 
%    

function numden
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/numden.m ---
%
% NUMDEN Numerator and denominator of a symbolic expression.
%    [N,D] = NUMDEN(A) converts each element of A to a rational 
%    form where the numerator and denominator are relatively prime 
%    polynomials with integer coefficients. 
% 
%    Examples: 
%       [n,d] = numden(sym(4/5)) returns n = 4 and d = 5.
%       [n,d] = numden(x/y + y/x) returns
%          n = x^2+y^2 , d = y*x

function horner
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/horner.m ---
%
% HORNER Horner polynomial representation.
%    HORNER(P) transforms the symbolic polynomial P into its Horner,
%    or nested, representation.
% 
%    Example:
%        horner(x^3-6*x^2+11*x-6) returns
%            x*(x*(x-6)+11)-6

function subexpr
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/subexpr.m ---
%
% SUBEXPR Rewrite in terms of common subexpressions.
%    [Y,SIGMA] = SUBEXPR(X,SIGMA) or [Y,SIGMA] = SUBEXPR(X,'SIGMA')
%    rewrites the symbolic expression X in terms of its common
%    subexpressions. These are the subexpressions that are written
%    as %1, %2, etc. by PRETTY(S).
%    
%    Example:
%       t = solve('a*x^3+b*x^2+c*x+d = 0');
%       [r,s] = subexpr(t,'s');
% 
%    

function subs
%MATLAB Tour Partial Function Help:  sym_con
%
%  Mu-Analysis and Synthesis Toolbox.
% 
%  Mat Files
% 
% 	F14_nom.mat	- Example file used by ex_f14ic ex_f14s1 ex_f14tp ex_f14wt
% 	ss_cont.mat	- Example file
% 
%  Example Files
% 
% 	ex1		- Example file
% 	ex1d		- Example file
% 	ex1t		- Example file
% 	ex_f14ic	- Example file
% 	ex_f14mu	- Example file
% 	ex_f14s1	- Example file
% 	ex_f14s2	- Example file
% 	ex_f14tp	- Example file
% 	ex_f14wt	- Example file called by ex_f14ic
% 	ex_mkclp	- Example file
% 	ex_mkpl		- Example file
% 	ex_ml1		- Example file
% 	ex_mmmk		- Example file called by mimo_margs
% 	ex_unc		- Example file
% 	ex_unic		- Example file
% 	ex_uspl		- Example file
% 	ex_usrp		- Example file
% 	ex_usti		- Example file
% 	ex_usti2	- Example file
% 	ex_ustr		- Example file called by ex_ustr2 ex_ustrd
% 	ex_ustr2	- Example file
% 	ex_ustrd	- Example file
% 	ex_wcp		- Example file
% 	formloop	- generic feedback loop interconnect, used in examples
% 	fow		- make first-order weight, used in examples
% 	gainph_ex	- Example file
% 	himat_de	- Example file
% 	himat_dk	- Example file
% 	himatic		- Example file called by mhimatic
% 	mhimatic	- Example file
% 	mimo_margs	- Example file
% 	mk_acnom	- Example file called by mk_olic mk_olsim
% 	mk_act		- Example file called by mk_olic mk_olsim
% 	mk_olic		- Example file
% 	mk_olsim	- Example file
% 	mk_pert		- Example file
% 	mk_wts		- Example file called by mk_olic mk_olsim
% 	mkhic		- Example file
% 	mkhicn		- Example file
% 	mkhimat		- Example file
% 	mkklp		- Example file
% 	mloop_ma	- Example file
% 	msdemo1		- Example file
% 	msdemo2		- Example file
% 	muexamp		- Example file
% 	olhimic		- Example file
% 	reducek		- simple controller order reduction, used in examples
% 	rsexamp		- Example file
% 	rsexamp_crc	- Example file
% 	ssic		- Example file called by tssic
% 	tankdemo	- Example file
% 	trsp_ex		- Example file
% 	tssic		- Example file
% 
%  CMEX source & dummies
% 
% 	amevlp.c	- CMEX executable called by genmu mu bub bubd gebub gebubd
% 	amevlp		- dummy m-file to cover missing amevlp.c
% 	amhxv.c		- c subroutine called by amevlp.c
% 	amhxy.c		- C subroutine called by amevlp.c
% 	amhxz.c		- C subroutine called by amevlp.c
% 	amhyv.c		- C subroutine called by amevlp.c
% 	amhyz.c		- C subroutine called by amevlp.c
% 	amhzv.c		- C subroutine called by amevlp.c
% 	amibndv.c	- CMEX executable called by genmu mu bub bubd gebub gebubd
% 	amibndv		- dummy m-file to cover missing amibndv.c
% 	amilowxy.c	- CMEX executable called by genmu mu bub bubd gebub gebubd
% 	amilowxy	- dummy m-file to cover missing amilowxy.c
% 	amiuppxy.c	- CMEX executable called by genmu mu bub bubd gebub gebubd
% 	amiuppxy	- dummy m-file to cover missing amiuppxy.c
% 	amxyzv.c	- C subroutine called by atxa.c
% 	atxa.c		- C subroutine called by amxyzv.c
% 	ghvvcp.c	- C subroutine called by amevlp.c
% 	ghxxc.c		- C subroutine called by amevlp.c
% 	ghyyc.c		- C subroutine called by amevlp.c
% 	ghzzc.c		- C subroutine called by amevlp.c
% 
%  Dedicated subroutines to Commands
% 
% 	a2ynrow		- called by mu genmu
% 	addrunf		- called by wsguin
% 	agv2str		- called by dkitgui dtrsp sdtrsp trsp dkparmcb parmwin tabed
% 	allocpim	- called by mu amiq2sol bub bubd gebub gebubd
% 	amiq2sol	- called by bub bubd gebub gebubd
% 	autod		- called by tankdemo
% 	axxbc		- called by h2norm sdecomp ham2schr
% 	bilins2z	- called by dhfsyn dhfsyn
% 	bilinz2s	- called by dhfnorm dhfsynp_c sdhfnorm sdn_step
% 	blknrms		- called by blknorm
% 	bub		- called by genmu mu
% 	bubd		- called by genmu mu
% 	cgivens		- called by csord
% 	chhsparm	- called by dkit
% 	chomega		- called by dkit
% 	chstr		- called by pass2
% 	co2di		- called by fitsys msf msfbatch
% 	colbut		- called by dkitgui dataent
% 	comple		- called by many programs
% 	compnorm	- called by sdhfnorm sdhfsyn
% 	dand		- called by rub
% 	dang		- called by rub
% 	dataent		- called by dkitgui simgui dk_able gdataent
% 	dcalc		- called by hankmr
% 	deebal		- called by rub
% 	deladdc		- called by simgui
% 	delrunf		- called by dkitgui wsguin
% 	dfitgui		- called by dkitgui dfitgui
% 	dhinf_p		- called by dhfsynf
% 	di2co		- called by fitsys msf msfbatch
% 	dk_able		- called by dkitgui dfitgui dkparmcb dkychose omframe rready
% 	dk_defin	- called by dkit himat_de
% 	dkdispla	- called by dkit
% 	dkparmcb	- called by dkitgui
% 	dkuchose	- called by dkitgui
% 	dkychose	- called by dkitgui
% 	dypertsb	- called by dypert
% 	extsmp		- called by fitsys msf msfbatch
% 	findmuw		- called by dkit dkitgui simgui vplot addrunf delrunf wsguin
% 	findrunf	- finds all running MU-GUIS
% 	findsys		- called by pass2
% 	fitchose	- called by msf
% 	flatten		- called by genphase
% 	fmfixbas	- called by fmlinp mffixbas
% 	fminfo		- called by wsminfo
% 	fmlp		- called by fmlinp
% 	gaino		- called by sysic
% 	gcnvert		- called by gebub gebubd
% 	gdataent	- called by simgui
% 	gdataevl	- called by dkitgui simgui dataent gdataent
% 	gebub		- called by genmu
% 	gebubd		- called by genmu
% 	geestep		- called by rub
% 	genlft		- called by starp redstar
% 	geosplit	- called by hinfnorm linfnorm
% 	gguivar		- Get GUI variable, called by many programs
% 	gjb2		- called by simgui scrolltb
% 	goptvl		- called by genmudiagnose mudiagnose rub
% 	gpredict	- called by hinfsyn
% 	grabvar		- called by mkdragic
% 	h2v		- called by simgui gguivar mkmulink sguivar
% 	ham2schr	- called by sdhfnorm sdhfsyn sdequiv
% 	helpxpii	- called by bub bubd gebub gebubd
% 	hinf_c		- called by hinfsyn[k] hinfe_c
% 	hinf_gam	- called by hinfsyn hinfsyne
% 	hinf_sp		- called by hinf_c hinf_gam hinf_st hinfe_c
% 	hinf_st		- called by hinfsyn hinfsyne
% 	hinfchk		- called by hinfnorm sdn_step
% 	hinfe_c		- called by hinfsyne[ka]
% 	hinffi_c	- called by hinffi[k]
% 	hinffi_g	- called by hinffi
% 	hinffi_p	- called by hinffi hinffi_c hinffi_g hinffi_t
% 	hinffi_t	- called by hinffi
% 	inpstuff	- called by sysic
% 	ipii		- Insert Packed Index Item
% 	jwhamtst	- called by hinfchk
% 	kfm		- delete all figures, and clear muTools globals
% 	ksum		- called by fitmag fitmaglp sclout sel autod dfitgui
% 	lamb		- called by rub
% 	ldpim		- called by minfo allocpim fminfo helpxpii ipii ldpim xpii
% 	linp		- called by magfit
% 	looptst		- called by fitmag fitmaglp
% 	mamilc		- called by bub bubd gebub gebubd
% 	mamiscl		- called by bub bubd gebub gebubd mamilc
% 	mdipii		- called by simgui
% 	mdpimdel	- called by simgui
% 	mdxpii		- called by simgui mdpimdel tabed
% 	mffixbas	- called by mflinp
% 	mflinp		- called by magfit
% 	mflp		- called by mflinp
% 	mhhparms	- called by dkit
% 	mkdragic	- called by scrtxtn
% 	mkdragtx	- called by dkitgui simgui wsguin
% 	mkmulink	- called by dkitgui
% 	mknorm		- called by dkitgui simgui
% 	mkours		- called by dkitgui simgui findmuw
% 	mkth		- called by dfitgui
% 	mtblanks	- called by sysic inpstuff namstuff pass1 pass2
% 	muclear		- called by kfm
% 	mucnvert	- called by bub bubd mucnvert
% 	mudeclar	- called by dkitgui simgui wsguin
% 	mudkaf		- called by msf msfbatch
% 	muexport	- called by dkitgui simgui
% 	mvtext		- called by mkdragic
% 	namstuff	- called by sysic
% 	nd2ssms		- called by nd2sys
% 	newd		- called by rub
% 	newga		- called by rub
% 	newub		- called by rub
% 	nicetod		- called by wsguicb wsguin
% 	notherdk	- called by dkit
% 	ocsf		- called by sncfbal srelbal
% 	omegavl		- called by dkitgui
% 	omframe		- called by dkitgui
% 	onealpha	- called by wcperf
% 	oniter		- called by dkitgui
% 	orsf		- called by sdecomp sncfbal srelbal
% 	ourslid		- called by scrolltb tabed
% 	parmwin		- called by dkitgui simgui gdataent wsguin
% 	pass1		- called by sysic
% 	pass2		- called by sysic
% 	pass3		- called by sysic
% 	prefit		- called by dkitgui dfitgui
% 	ptrs		- called by mu and subroutines
% 	pullaprt	- called by wsguic
% 	qrsc		- called by sjh6
% 	redstar		- called by starp redstar
% 	reindex		- called by dypert mu muunwrap unwrapp
% 	reomega		- called by dkit
% 	rerunhi		- called by dkit
% 	rready		- called by dkitgui omframe
% 	rub		- called by dypert mu
% 	rubind		- called by dypert mu muunwrap unwrapp
% 	rublow		- called by rub
% 	rupert		- called by rublow
% 	ruqvsol		- called by cmmusyn genmu
% 	ruqvsolb	- called by cmmusyn
% 	sclmublk	- called by sclmublk
% 	scrolltb	- called by dkitgui simgui dfitgui rready
% 	scrtxtn		- called by dkitgui simgui wsguin
% 	sdequiv		- called by sdhfsyn sdn_step
% 	sdn_step	- called by sdhfnorm
% 	seesub		- called by seesys
% 	sguivar		- Set GUI variable, called by many programs
% 	sigmaub		- called by mu mu sigmaub sigmaub
% 	sim2str		- called by sim2str sim2str
% 	simplemu	- called by simplemu
% 	simprmu		- called by simprmu
% 	sisoloop	- called by ex_ustr2
% 	sjh6		- called by clyap sncfbal srelbal sysbal
% 	sm2vec		- called by bub bubd gebub gebubd
% 	ssm2vec		- called by bub bubd gebub gebubd
% 	stripemp	- called by oniter
% 	swapiv		- Swap independent variables
% 	sylv		- called by h2norm axxbc
% 	syscl		- not called, may be used in debugging
% 	tabed		- called by dkitgui
% 	terpol		- called by dtrsp genphase sdtrsp trsp vinterp vterp
% 	terpolb		- called by genphase
% 	updownb		- called by simgui
% 	updownb2	- called by simgui
% 	var2sep		- called by mamilc
% 	vec2sm		- called by amiq2sol
% 	vec2ssm		- called by amiq2sol
% 	wsguic		- called by wsgui wsguin
% 	wsguicb		- called by wsguin
% 	wsguin		- called by wsgui
% 	wsminfo		- called by wsguin
% 	xpii		- Extract Packed Index Item
% 	ynftdami	- called by mu
% 	yublksel	- called by dkitgui
%
%
%subs is both a directory and a function.
%
% SUBS   Symbolic substitution.
%    SUBS(S) replaces all the variables in the symbolic expression S with
%    values obtained from the calling function, or the MATLAB workspace.
%    
%    SUBS(S,NEW) replaces the free symbolic variable in S with NEW.
%    SUBS(S,OLD,NEW) replaces OLD with NEW in the symbolic expression S.
%    OLD is a symbolic variable, a string representing a variable name, or
%    a string (quoted) expression. NEW is a symbolic or numeric variable
%    or expression.
% 
%    If OLD and NEW are cell arrays of the same size, each element of OLD is
%    replaced by the corresponding element of NEW.  If S and OLD are scalars
%    and NEW is an array or cell array, the scalars are expanded to produce
%    an array result.  If NEW is a cell array of numeric matrices, the
%    substitutions are performed elementwise (i.e., subs(x*y,{x,y},{A,B})
%    returns A.*B when A and B are numeric).
% 
%    If SUBS(S,OLD,NEW) does not change S, then SUBS(S,NEW,OLD) is tried.
%    This provides backwards compatibility with previous versions and 
%    eliminates the need to remember the order of the arguments.
%    SUBS(S,OLD,NEW,0) does not switch the arguments if S does not change.
% 
%    Examples:
%      Single input:
%        Suppose a = 980 and C1 = 3 exist in the workspace.
%        The statement
%           y = dsolve('Dy = -a*y')
%        produces
%           y = exp(-a*t)*C1
%        Then the statement
%           subs(y)
%        produces
%           ans = 3*exp(-980*t)
% 
%      Single Substitution:
%        subs(a+b,a,4) returns 4+b.
% 
%      Multiple Substitutions:
%        subs(cos(a)+sin(b),{a,b},{sym('alpha'),2}) returns
%        cos(alpha)+sin(2)
%    
%      Scalar Expansion Case: 
%        subs(exp(a*t),'a',-magic(2)) returns
% 
%        [   exp(-t), exp(-3*t)]
%        [ exp(-4*t), exp(-2*t)]
% 
%      Multiple Scalar Expansion:
%        subs(x*y,{x,y},{[0 1;-1 0],[1 -1;-2 1]}) returns
%        [  0, -1]
%        [  2,  0]
% 
%    

function solve
%MATLAB Tour Partial Function Help:  sym_con
%
% SOLVE  Symbolic solution of algebraic equations.
%    SOLVE('eqn1','eqn2',...,'eqnN')
%    SOLVE('eqn1','eqn2',...,'eqnN','var1,var2,...,varN')
%    SOLVE('eqn1','eqn2',...,'eqnN','var1','var2',...'varN')
% 
%    The eqns are symbolic expressions or strings specifying equations.  The
%    vars are symbolic variables or strings specifying the unknown variables.
%    SOLVE seeks zeros of the expressions or solutions of the equations.
%    If not specified, the unknowns in the system are determined by FINDSYM.
%    If no analytical solution is found and the number of equations equals
%    the number of dependent variables, a numeric solution is attempted.
% 
%    Three different types of output are possible.  For one equation and one
%    output, the resulting solution is returned, with multiple solutions to
%    a nonlinear equation in a symbolic vector.  For several equations and
%    an equal number of outputs, the results are sorted in lexicographic
%    order and assigned to the outputs.  For several equations and a single
%    output, a structure containing the solutions is returned.
% 
%    Examples:
% 
%       solve('p*sin(x) = r') chooses 'x' as the unknown and returns
% 
%         ans =
%         asin(r/p)
% 
%       [x,y] = solve('x^2 + x*y + y = 3','x^2 - 4*x + 3 = 0') returns
% 
%         x =
%         [ 1]
%         [ 3]
% 
%         y =
%         [    1]
%         [ -3/2]
% 
%       S = solve('x^2*y^2 - 2*x - 1 = 0','x^2 - y^2 - 1 = 0') returns
%       the solutions in a structure.
% 
%         S =
%           x: [8x1 sym]
%           y: [8x1 sym]
% 
%       [u,v] = solve('a*u^2 + v^2 = 0','u - v = 1') regards 'a' as a
%       parameter and solves the two equations for u and v.
% 
%       S = solve('a*u^2 + v^2','u - v = 1','a,u') regards 'v' as a
%       parameter, solves the two equations, and returns S.a and S.u.
% 
%       [a,u,v] = solve('a*u^2 + v^2','u - v = 1','a^2 - 5*a + 6') solves
%       the three equations for a, u and v.
% 
%       [x,y] = solve('sin(x+y)-exp(x)*y = 0','x^2-y = 2') cannot find
%       an analytic solution, so returns a numeric solution.
% 
%    

function dsolve
%MATLAB Tour Partial Function Help:  sym_con
%
% DSOLVE Symbolic solution of ordinary differential equations.
%    DSOLVE('eqn1','eqn2', ...) accepts symbolic equations representing
%    ordinary differential equations and initial conditions.  Several
%    equations or initial conditions may be grouped together, separated
%    by commas, in a single input argument.
% 
%    By default, the independent variable is 't'. The independent variable
%    may be changed from 't' to some other symbolic variable by including
%    that variable as the last input argument.
% 
%    The letter 'D' denotes differentiation with respect to the independent
%    variable, i.e. usually d/dt.  A "D" followed by a digit denotes
%    repeated differentiation; e.g., D2 is d^2/dt^2.  Any characters
%    immediately following these differentiation operators are taken to be
%    the dependent variables; e.g., D3y denotes the third derivative
%    of y(t). Note that the names of symbolic variables should not contain
%    the letter "D".
% 
%    Initial conditions are specified by equations like 'y(a)=b' or
%    'Dy(a) = b' where y is one of the dependent variables and a and b are
%    constants.  If the number of initial conditions given is less than the
%    number of dependent variables, the resulting solutions will obtain
%    arbitrary constants, C1, C2, etc.
% 
%    Three different types of output are possible.  For one equation and one
%    output, the resulting solution is returned, with multiple solutions to
%    a nonlinear equation in a symbolic vector.  For several equations and
%    an equal number of outputs, the results are sorted in lexicographic
%    order and assigned to the outputs.  For several equations and a single
%    output, a structure containing the solutions is returned.
% 
%    If no closed-form (explicit) solution is found, an implicit solution is
%    attempted.  When an implicit solution is returned, a warning is given.
%    If neither an explicit nor implicit solution can be computed, then a
%    warning is given and the empty sym is returned.  In some cases concerning
%    nonlinear equations, the output will be an equivalent lower order differential
%    equation or an integral.
% 
%    Examples:
% 
%       dsolve('Dx = -a*x') returns
% 
%         ans = exp(-a*t)*C1
% 
%       x = dsolve('Dx = -a*x','x(0) = 1','s') returns
% 
%         x = exp(-a*s)
% 
%       y = dsolve('(Dy)^2 + y^2 = 1','y(0) = 0') returns
%  
%         y =
%         [  sin(t)]
%         [ -sin(t)]
% 
%       S = dsolve('Df = f + g','Dg = -f + g','f(0) = 1','g(0) = 2')
%       returns a structure S with fields
% 
%         S.f = exp(t)*cos(t)+2*exp(t)*sin(t)
%         S.g = -exp(t)*sin(t)+2*exp(t)*cos(t)
% 
%       Y = dsolve('Dy = y^2*(1-y)')
%       Warning: Explicit solution could not be found; implicit solution returned.
%       Y =
%       t+1/y-log(y)+log(-1+y)+C1=0
% 
%       dsolve('Df = f + sin(t)', 'f(pi/2) = 0')
%       dsolve('D2y = -a^2*y', 'y(0) = 1, Dy(pi/a) = 0')
%       S = dsolve('Dx = y', 'Dy = -x', 'x(0)=0', 'y(0)=1')
%       S = dsolve('Du=v, Dv=w, Dw=-u','u(0)=0, v(0)=0, w(0)=1')
%       w = dsolve('D3w = -w','w(0)=1, Dw(0)=0, D2w(0)=0')
%       y = dsolve('D2y = sin(y)'); pretty(y)
% 
%    

function finverse
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/finverse.m ---
%
% FINVERSE Functional inverse.
%    g = FINVERSE(f) returns the functional inverse of f. 
%    f is a scalar sym representing a function of exactly 
%    one symbolic variable, say 'x'. Then g is a scalar sym
%    that satisfies g(f(x)) = x.
% 
%    g = FINVERSE(f,v) uses the symbolic variable v, where v is
%    a sym, as the independent variable. Then g is a scalar 
%    sym that satisfies g(f(v)) = v. Use this form when f contains 
%    more than one symbolic variable.
% 
%    Examples:
%       finverse(1/tan(x)) returns atan(1/x).
% 
%       f = x^2+y;
%       finverse(f,y) returns -x^2+y.
%       finverse(f) returns (-y+x)^(1/2) and a warning that the 
%          inverse is not unique.
% 
%    

function compose
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/compose.m ---
%
% COMPOSE Functional composition.
%    COMPOSE(f,g) returns f(g(y)) where f = f(x) and g = g(y). 
%    Here x is the symbolic variable of f as defined by FINDSYM and 
%    y is the symbolic variable of g as defined by FINDSYM.
% 
%    COMPOSE(f,g,z) returns f(g(z)) where f = f(x), g = g(y), and
%    x and y are the symbolic variables of f and g as defined by 
%    FINDSYM. 
% 
%    COMPOSE(f,g,x,z) returns f(g(z)) and makes x the independent 
%    variable for f.  That is, if f = cos(x/t), then COMPOSE(f,g,x,z)
%    returns cos(g(z)/t) whereas COMPOSE(f,g,t,z) returns cos(x/g(z)).
%   
%    COMPOSE(f,g,x,y,z) returns f(g(z)) and makes x the independent
%    variable for f and y the independent variable for g.  For
%    f = cos(x/t) and g = sin(y/u), COMPOSE(f,g,x,y,z) returns
%    cos(sin(z/u)/t) whereas COMPOSE(f,g,x,u,z) returns cos(sin(y/z)/t).
%  
%    Examples:
%     syms x y z t u;
%     f = 1/(1 + x^2); g = sin(y); h = x^t; p = exp(-y/u);
%     compose(f,g)         returns   1/(1+sin(y)^2) 
%     compose(f,g,t)       returns   1/(1+sin(t)^2)
%     compose(h,g,x,z)     returns   sin(z)^t
%     compose(h,g,t,z)     returns   x^sin(z)
%     compose(h,p,x,y,z)   returns   exp(-z/u)^t 
%     compose(h,p,t,u,z)   returns   x^exp(-y/z) 
% 
%    

function vpa
%MATLAB Tour Partial Function Help:  sym_con
%
% VPA    Variable precision arithmetic. 
%    R = VPA(S) numerically evaluates each element of the double matrix
%    S using variable precision floating point arithmetic with D decimal 
%    digit accuracy, where D is the current setting of DIGITS. 
%    The resulting R is a SYM.
%  
%    VPA(S,D) uses D digits, instead of the current setting of DIGITS.
%    D is an integer or the SYM representation of a number.
% 
%    Examples:
%       vpa(pi,780) shows six consecutive 9's near digit 770 in the
%          decimal expansion of pi.
% 
%       vpa(hilb(2),5) returns
% 
%          [    1., .50000]
%          [.50000, .33333]
% 
%    

function digits
%MATLAB Tour Partial Function Help:  sym_con
%
% DIGITS Set Maple's Digits.
%    Digits determines the accuracy of Maple's numeric computations.
%    DIGITS, by itself, displays the current setting of Digits.
%    DIGITS(D) sets Digits to D for subsequent calculations. D is an 
%       integer, or a string or sym representing an integer.
%    D = DIGITS returns the current setting of Digits. D is an integer.
% 
%    

function fourier
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/fourier.m ---
%
% FOURIER Fourier integral transform.
%    F = FOURIER(f) is the Fourier transform of the sym scalar f
%    with default independent variable x.  The default return is
%    a function of w.
%    If f = f(w), then FOURIER returns a function of t:  F = F(t).
%    By definition, F(w) = int(f(x)*exp(-i*w*x),x,-inf,inf), where
%    the integration above proceeds with respect to x (the symbolic
%    variable in f as determined by FINDSYM).
% 
%    F = FOURIER(f,v) makes F a function of the sym v instead of 
%        the default w:
%    FOURIER(f,v) <=> F(v) = int(f(x)*exp(-i*v*x),x,-inf,inf).
% 
%    FOURIER(f,u,v) makes f a function of u instead of the
%        default x. The integration is then with respect to u.
%    FOURIER(f,u,v) <=> F(v) = int(f(u)*exp(-i*v*u),u,-inf,inf).
% 
%    Examples:
%     syms t v w x
%     fourier(1/t)   returns   i*pi*(Heaviside(-w)-Heaviside(w))
%     fourier(exp(-x^2),x,t)   returns   pi^(1/2)*exp(-1/4*t^2)
%     fourier(exp(-t)*sym('Heaviside(t)'),v)   returns   1/(1+i*v)
%     fourier(diff(sym('F(x)')),x,w)   returns   i*w*fourier(F(x),x,w)
% 
%    

function laplace
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/laplace.m ---
%
% LAPLACE Laplace transform.
%    L = LAPLACE(F) is the Laplace transform of the scalar sym F with
%    default independent variable t.  The default return is a function
%    of s.  If F = F(s), then LAPLACE returns a function of t:  L = L(t).
%    By definition L(s) = int(F(t)*exp(-s*t),0,inf), where integration
%    occurs with respect to t.
% 
%    L = LAPLACE(F,t) makes L a function of t instead of the default s:
%    LAPLACE(F,t) <=> L(t) = int(F(x)*exp(-t*x),0,inf).
% 
%    L = LAPLACE(F,w,z) makes L a function of z instead of the
%    default s (integration with respect to w).
%    LAPLACE(F,w,z) <=> L(z) = int(F(w)*exp(-z*w),0,inf).
% 
%    Examples:
%       syms a s t w x
%       laplace(t^5)           returns   120/s^6
%       laplace(exp(a*s))      returns   1/(t-a)
%       laplace(sin(w*x),t)    returns   w/(t^2+w^2)
%       laplace(cos(x*w),w,t)  returns   t/(t^2+x^2)
%       laplace(x^sym(3/2),t)  returns   3/4*pi^(1/2)/t^(5/2)
%       laplace(diff(sym('F(t)')))   returns   laplace(F(t),t,s)*s-F(0)
% 
%    

function ztrans
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/ztrans.m ---
%
% ZTRANS Z-transform.
%    F = ZTRANS(f) is the Z-transform of the scalar sym f with default
%    independent variable n.  The default return is a function of z:
%    f = f(n) => F = F(z).  The Z-transform of f is defined as: 
%       F(z) = symsum(f(n)/z^n, n, 0, inf),
%    where n is f's symbolic variable as determined by FINDSYM.  If
%    f = f(z), then ZTRANS(f) returns a function of w:  F = F(w).
% 
%    F = ZTRANS(f,w) makes F a function of the sym w instead of the
%    default z:  ZTRANS(f,w) <=> F(w) = symsum(f(n)/w^n, n, 0, inf).
% 
%    F = ZTRANS(f,k,w) takes f to be a function of the sym variable k:
%    ZTRANS(f,k,w) <=> F(w) = symsum(f(k)/w^k, k, 0, inf).
% 
%    Examples:
%       syms k n w z
%       ztrans(2^n)           returns  z/(z-2)
%       ztrans(sin(k*n),w)    returns  sin(k)*w/(1-2*w*cos(k)+w^2)
%       ztrans(cos(n*k),k,z)  returns  z*(-cos(n)+z)/(-2*z*cos(n)+z^2+1)
%       ztrans(cos(n*k),n,w)  returns  w*(-cos(k)+w)/(-2*w*cos(k)+w^2+1)
%       ztrans(sym('f(n+1)')) returns  z*ztrans(f(n),n,z)-f(0)*z
% 
%    

function ifourier
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/ifourier.m ---
%
% IFOURIER Inverse Fourier integral transform.
%    f = IFOURIER(F) is the inverse Fourier transform of the scalar sym F
%    with default independent variable w.  The default return is a
%    function of x.  The inverse Fourier transform is applied to a
%    function of w and returns a function of x: F = F(w) => f = f(x).
%    If F = F(x), then IFOURIER returns a function of t: f = f(t). By
%    definition, f(x) = 1/(2*pi) * int(F(w)*exp(i*w*x),w,-inf,inf) and the 
%    integration is taken with respect to w.
% 
%    f = IFOURIER(F,u) makes f a function of u instead of the default x:
%    IFOURIER(F,u) <=> f(u) = 1/(2*pi) * int(F(w)*exp(i*w*u,w,-inf,inf).  
%    Here u is a scalar sym (integration with respect to w).
% 
%    f = IFOURIER(F,v,u) takes F to be a function of v instead of the
%    default w:  IFOURIER(F,v,u) <=>
%    f(u) = 1/(2*pi) * int(F(v)*exp(i*v*u,v,-inf,inf),
%    integration with respect to v.
% 
%    Examples:
%     syms t u w x
%     ifourier(w*exp(-3*w)*sym('Heaviside(w)'))   returns   1/2/pi/(3-i*t)^2
% 
%     ifourier(1/(1 + w^2),u)   returns
%          1/2*exp(-u)*Heaviside(u)+1/2*exp(u)*Heaviside(-u)
% 
%     ifourier(v/(1 + w^2),v,u)   returns   i/(1+w^2)*Dirac(1,-u)
%          
%     ifourier(sym('fourier(f(x),x,w)'),w,x)   returns   f(x)
% 
%    

function ilaplace
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/ilaplace.m ---
%
% ILAPLACE Inverse Laplace transform.
%    F = ILAPLACE(L) is the inverse Laplace transform of the scalar sym L
%    with default independent variable s.  The default return is a
%    function of t.  If L = L(t), then ILAPLACE returns a function of x:
%    F = F(x).
%    By definition, F(t) = int(L(s)*exp(s*t),s,c-i*inf,c+i*inf)
%    where c is a real number selected so that all singularities 
%    of L(s) are to the left of the line s = c, i = sqrt(-1), and 
%    the integration is taken with respect to s.
% 
%    F = ILAPLACE(L,y) makes F a function of y instead of the default t:
%        ILAPLACE(L,y) <=> F(y) = int(L(y)*exp(s*y),s,c-i*inf,c+i*inf).
%    Here y is a scalar sym.
% 
%    F = ILAPLACE(L,y,x) makes F a function of x instead of the default t:
%    ILAPLACE(L,y,x) <=> F(y) = int(L(y)*exp(x*y),y,c-i*inf,c+i*inf),
%    integration is taken with respect to y.
% 
%    Examples:
%       syms s t w x y
%       ilaplace(1/(s-1))              returns   exp(t)
%       ilaplace(1/(t^2+1))            returns   sin(x)
%       ilaplace(t^(-sym(5/2)),x)      returns   4/3/pi^(1/2)*x^(3/2)
%       ilaplace(y/(y^2 + w^2),y,x)    returns   cos(w*x)
%       ilaplace(sym('laplace(F(x),x,s)'),s,x)   returns   F(x)
% 
%    

function iztrans
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/iztrans.m ---
%
% IZTRANS Inverse Z-transform.
%    f = IZTRANS(F) is the inverse Z-transform of the scalar sym F with
%    default independent variable z.  The default return is a function 
%    of n:  F = F(z) => f = f(n).  If F = F(n), then IZTRANS returns a
%    function of k: f = f(k).
%    f = IZTRANS(F,k) makes f a function of k instead of the default n.
%    Here m is a scalar sym.
%    f = IZTRANS(F,w,k) takes F to be a function of w instead of the
%    default symvar(F) and returns a function of k:  F = F(w) & f = f(k).
% 
%    Examples:
%       iztrans(z/(z-2))        returns   2^n
%       iztrans(exp(x/z),z,k)   returns   x^k/k!
% 
%    

function double
%MATLAB Tour Partial Function Help:  sym_con
%
% DOUBLE Convert to double precision.
%    DOUBLE(X) returns the double precision value for X.
%    If X is already a double precision array, DOUBLE has
%    no effect.
% 
%    DOUBLE is called for the expressions in FOR, IF, and WHILE loops
%    if the expression isn't already double precision.  DOUBLE should
%    be overloaded for all objects where it makes sense to convert it
%    into a double precision value.
%
% Overloaded methods
%    help opaque/double.m
%    help sftransition/double.m
%    help sfjunction/double.m
%    help sym/double.m
%    help tlchandle/double.m
%    help rptsp/double.m
%    help rptcp/double.m
%    help object/double.m

function poly2sym
%MATLAB Tour Partial Function Help:  sym_con
%
% POLY2SYM Polynomial coefficient vector to symbolic polynomial.
%    POLY2SYM(C) is a symbolic polynomial in 'x' with coefficients
%    from the vector C.
%    POLY2SYM(C,'V') and POLY2SYM(C,SYM('V') both use the symbolic
%    variable specified by the second argument.
%  
%    Example:
%        poly2sym([1 0 -2 -5])
%    is
%        x^3-2*x-5
% 
%        poly2sym([1 0 -2 -5],'t')
%    and
%        t = sym('t')
%        poly2sym([1 0 -2 -5],t)
%    both return
%        t^3-2*t-5
% 
%    

function sym2poly
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/sym2poly.m ---
%
% SYM2POLY Symbolic polynomial to polynomial coefficient vector.
%    SYM2POLY(P) returns a row vector containing the coefficients 
%    of the symbolic polynomial P.
% 
%    Example:
%       sym2poly(x^3 - 2*x - 5) returns [1 0 -2 -5].
% 
%    

function char
%MATLAB Tour Partial Function Help:  sym_con
%
% CHAR Create character array (string).
%    S = CHAR(X) converts the array X that contains positive integers
%    representing character codes into a MATLAB character array (the first
%    127 codes are ASCII). The actual characters displayed depends on the
%    character set encoding for a given font.  The result for any elements
%    of X outside the range from 0 to 65535 is not defined (and may vary
%    from platform to platform).  Use DOUBLE to convert a character array
%    into its numeric codes.
% 
%    S = CHAR(C), when C is a cell array of strings, places each 
%    element of C into the rows of the character array S.  Use CELLSTR to
%    convert back.
% 
%    S = CHAR(T1,T2,T3,..) forms the character array S containing the text
%    strings T1,T2,T3,... as rows.  Automatically pads each string with
%    blanks in order to form a valid matrix.  Each text parameter, Ti,
%    can itself be a character array.  This allows the creation of
%    arbitrarily large character arrays.  Empty strings are significant.
% 
%    

function sym
%MATLAB Tour Partial Function Help:  sym_con
%
% SYM    Construct symbolic numbers, variables and objects.
%    S = SYM(A) constructs an object S, of class 'sym', from A.
%    If the input argument is a string, the result is a symbolic number
%    or variable.  If the input argument is a numeric scalar or matrix,
%    the result is a symbolic representation of the given numeric values.
% 
%    x = sym('x') creates the symbolic variable with name 'x' and stores the
%    result in x.  x = sym('x','real') also assumes that x is real, so that
%    conj(x) is equal to x.  alpha = sym('alpha') and r = sym('Rho','real')
%    are other examples.  Similarly, k = sym('k','positive') makes k a 
%    positive (real) variable.  x = sym('x','unreal') makes x a purely
%    formal variable with no additional properties (i.e., insures that x
%    is NEITHER real NOR positive).
%    

function syms
%MATLAB Tour Partial Function Help:  sym_con
%
% SYMS   Short-cut for constructing symbolic objects.
%    SYMS arg1 arg2 ...
%    is short-hand notation for
%       arg1 = sym('arg1');
%       arg2 = sym('arg2'); ...
% 
%    SYMS arg1 arg2 ... real
%    is short-hand notation for
%       arg1 = sym('arg1','real');
%       arg2 = sym('arg2','real'); ...
% 
%    SYMS arg1 arg2 ... positive
%    is short-hand notation for
%       arg1 = sym('arg1','positive');
%       arg2 = sym('arg2','positive'); ...
% 
%    SYMS arg1 arg2 ... unreal
%    is short-hand notation for
%       arg1 = sym('arg1','unreal');
%       arg2 = sym('arg2','unreal'); ...
% 
%    Each input argument must begin with a letter and must contain only
%    alphanumeric characters.
% 
%    By itself, SYMS lists the symbolic objects in the workspace.
% 
%    Examples:
%       syms x beta real
%    is equivalent to:
%       x = sym('x','real');
%       beta = sym('beta','real');
% 
%       syms k positive
%    is equivalent to:
%       k = sym('k','positive');
% 
%    To clear the symbolic objects x and beta of 'real' or 'positive' status, type
%       syms x beta unreal
% 
%    

function findsym
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/findsym.m ---
%
% FINDSYM Finds the symbolic variables in a symbolic expression or matrix.
%    FINDSYM(S), where S is a scalar or matrix sym, returns a string 
%    containing all of the symbolic variables appearing in S. The 
%    variables are returned in alphabetical order and are separated by
%    commas. If no symbolic variables are found, FINDSYM returns the
%    empty string.
% 
%    FINDSYM(S,N) returns the N symbolic variables closest to 'x'. 
% 
%    Examples:
%       findsym(alpha+a+b) returns
%        a, alpha, b
% 
%       findsym(cos(alpha)*b*x1 + 14*y,2) returns
%        x1,y
% 
%       findsym(y*(4+3*i) + 6*j) returns
%        y

function pretty
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/pretty.m ---
%
% PRETTY Pretty print a symbolic expression.
%    PRETTY(S) prints the symbolic expression S in a format that 
%    resembles type-set mathematics.
%    PRETTY(S,n) uses screen width n instead of the default 79.
% 
%    

function latex
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/latex.m ---
%
% LATEX  LaTeX representation of a symbolic expression.
%    LATEX(S) returns the LaTeX representation of the symbolic expression S.
% 
%    Examples:
%       syms x
%       f = taylor(log(1+x));
%       latex(f) =
%          x-1/2\,{x}^{2}+1/3\,{x}^{3}-1/4\,{x}^{4}+1/5\,{x}^{5}
% 
%       H = sym(hilb(3));
%       latex(H) =
%          \left [\begin {array}{ccc} 1&1/2&1/3\\\noalign{\medskip}1/2&1/3&1/4
%          \\\noalign{\medskip}1/3&1/4&1/5\end {array}\right ]
%      
%       syms alpha t
%       A = [alpha t alpha*t];
%       latex(A) =
%          \left [\begin {array}{ccc} \alpha&t&\alpha\,t\end {array}\right ]
% 
%    

function ccode
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/ccode.m ---
%
% CCODE  C code representation of a symbolic expression.
%    CCODE(S) returns a fragment of C that evaluates the symbolic expression S.
% 
%    Examples:
%       syms x
%       f = taylor(log(1+x));
%       ccode(f) =
% 
%          t0 = x-x*x/2.0+x*x*x/3.0-x*x*x*x/4.0+x*x*x*x*x/5.0;
% 
%       H = sym(hilb(3));
%       ccode(H) =
% 
%          H[0][0] = 1.0;          H[0][1] = 1.0/2.0;      H[0][2] = 1.0/3.0;
%          H[1][0] = 1.0/2.0;      H[1][1] = 1.0/3.0;      H[1][2] = 1.0/4.0;
%          H[2][0] = 1.0/3.0;      H[2][1] = 1.0/4.0;      H[2][2] = 1.0/5.0;
% 
%    

function fortran
%MATLAB Tour Partial Function Help:  sym_con
%
% --- help for sym/fortran.m ---
%
% FORTRAN  Fortran representation of a symbolic expression.
%    FORTRAN(S) is a fragment of Fortran that evaluates symbolic expression S.
% 
%    Examples:
%       syms x
%       f = taylor(log(1+x));
%       fortran(f) =
% 
%          t0 = x-x**2/2+x**3/3-x**4/4+x**5/5
% 
%       H = sym(hilb(3));
%       fortran(H) =
% 
%          H(1,1) = 1            H(1,2) = 1.E0/2.E0    H(1,3) = 1.E0/3.E0
%          H(2,1) = 1.E0/2.E0    H(2,2) = 1.E0/3.E0    H(2,3) = 1.E0/4.E0
%          H(3,1) = 1.E0/3.E0    H(3,2) = 1.E0/4.E0    H(3,3) = 1.E0/5.E0
% 
%    

function sinint
%MATLAB Tour Partial Function Help:  sym_con
%
% SININT Sine integral function.
%   SININT(x) = int(sin(t)/t,t,0,x).
% 
%   

function cosint
%MATLAB Tour Partial Function Help:  sym_con
%
% COSINT Cosine integral function.
%   COSINT(x) = Gamma + log(x) + int((cos(t)-1)/t,t,0,x)
%   where Gamma is Euler's constant, .57721566490153286060651209...
%   Euler's constant can be evaluated with vpa('eulergamma').
% 
%   

function zeta
%MATLAB Tour Partial Function Help:  sym_con
%
% ZETA   Symbolic Riemann zeta function.
%    ZETA(z) = sum(1/k^z,k,1,inf).
%    ZETA(n,z) = n-th derivative of ZETA(z)
%
% Overloaded methods
%    help sym/zeta.m

function lambertw
%MATLAB Tour Partial Function Help:  sym_con
%
% LAMBERTW Lambert's W function.
%    W = LAMBERTW(X) is the solution to w*exp(w) = x.
%    W = LAMBERTW(K,X) is the K-th branch of this multi-valued function.
%    Reference: Robert M. Corless, G. H. Gonnet, D. E. G. Hare,
%    D. J. Jeffrey, and D. E. Knuth, "On the Lambert W Function",
%    Advances in Computational Mathematics, volume 5, 1996, pp. 329-359.
%    Also available from:
%    http://pineapple.apmaths.uwo.ca/~rmc/papers/LambertW/index.html
%
% Overloaded methods
%    help sym/lambertw.m

function isvarname
%MATLAB Tour Partial Function Help:  sym_con
%
% ISVARNAME Check for a valid variable name.
%    ISVARNAME(S) is true if S is a valid MATLAB variable name.
%    A valid variable name is a character string of letters, digits and
%    underscores, with length <= 32 and the first character a letter.

function vectorize
%MATLAB Tour Partial Function Help:  sym_con
%
% VECTORIZE Vectorize expression.
%    VECTORIZE(S), when S is a string expression, inserts a '.' before
%    any '^', '*' or '/' in S.  The result is a character string.
% 
%    VECTORIZE(FCN), when FCN is an INLINE function object, vectorizes the
%    formula for FCN.  The result is the vectorized version of the INLINE
%    function.
% 
%    

function rsums
%MATLAB Tour Partial Function Help:  sym_con
%
% RSUMS  Interactive evaluation of Riemann sums.
%    RSUMS(f) approximates the integral of f by Riemann sums.
%    f is a string representing a function of exactly one variable.
%    RSUMS is usually called with the command line form, eg.
%       rsums exp(-5*x^2)
%
% Overloaded methods
%    help sym/rsums.m

function ezcontour
%MATLAB Tour Partial Function Help:  sym_con
%
% EZCONTOUR Easy to use contour plotter.
%    EZCONTOUR(f) plots the contour lines of f(x,y) using CONTOUR where
%    f is a string or symbolic expression representing a mathematical
%    function of two variables, say 'x' and 'y'.  The function f is 
%    plotted over the default domain -2*pi < x < 2*pi, -2*pi < y < 2*pi.
%    The computational grid is chosen according to the amount
%    of variation that occurs.
% 
%    EZCONTOUR(f,DOMAIN) plots f over the specified DOMAIN instead of the
%    default DOMAIN = [-2*pi,2*pi,-2*pi,2*pi].  The DOMAIN can be the
%    4-by-1 vector [xmin,xmax,ymin,ymax] or the 2-by-1 vector [a,b] (to
%    plot over a < x < b, a < y < b).
% 
%    If f is a function of the variables u and v (rather than x and y),
%    then the domain endpoints umin, umax, vmin, and vmax are sorted
%    alphabetically.  Thus, EZCONTOUR('u^2 - v^3',[0,1],[3,6]) plots the
%    contour lines for u^2 - v^3 over 0 < u < 1, 3 < v < 6.
% 
%    EZCONTOUR(...,N) plots f over the default domain using an N-by-N grid.
%    The default value for N is 60..
% 
%    ROTATE3D always on.  To rotate the graph, click and drag with your mouse.
% 
%    Examples:
%     f = ['3*(1-x)^2*exp(-(x^2) - (y+1)^2)' ... 
%        '- 10*(x/5 - x^3 - y^5)*exp(-x^2-y^2)' ... 
%        '- 1/3*exp(-(x+1)^2 - y^2)'];
%     ezcontour(f,[-pi,pi])
%     ezcontour('sin(sqrt(x^2+y^2))/sqrt(x^2+y^2)',[-6*pi,6*pi])
%     ezcontour('x*exp(-x^2 - y^2)')
%     ezcontour('-3*z/(1 + t^2 - z^2)',[-4,4],120)
%     ezcontour('sin(u)*sin(v)',[-2*pi,2*pi])
% 
%    

function ezcontourf
%MATLAB Tour Partial Function Help:  sym_con
%
% EZCONTOURF Easy to use filled contour plotter.
%    EZCONTOURF(f) plots the contour lines of f(x,y) using CONTOURF where
%    f is a string or symbolic expression representing a mathematical
%    function of two variables, say 'x' and 'y'.  The function f is 
%    plotted over the default domain -2*pi < x < 2*pi, -2*pi < y < 2*pi.
%    The computational grid is chosen according to the amount
%    of variation that occurs.
% 
%    EZCONTOURF(f,DOMAIN) plots f over the specified DOMAIN instead of the
%    default DOMAIN = [-2*pi,2*pi,-2*pi,2*pi].  The DOMAIN can be the
%    4-by-1 vector [xmin,xmax,ymin,ymax] or the 2-by-1 vector [a,b] (to
%    plot over a < x < b, a < y < b).
% 
%    If f is a function of the variables u and v (rather than x and y),
%    then the domain endpoints umin, umax, vmin, and vmax are sorted
%    alphabetically.  Thus, EZCONTOURF(u^2 - v^3,[0,1],[3,6]) plots the
%    contour lines for u^2 - v^3 over 0 < u < 1, 3 < v < 6.
% 
%    EZCONTOURF(...,N) plots f over the default domain using an N-by-N grid.
%    The default value for N is 60.
% 
%    ROTATE3D always on.  To rotate the graph, click and drag with your mouse.
% 
%    Examples:
%     f = ['3*(1-x)^2*exp(-(x^2) - (y+1)^2)' ... 
%        '- 10*(x/5 - x^3 - y^5)*exp(-x^2-y^2)' ... 
%        '- 1/3*exp(-(x+1)^2 - y^2)'];
%     ezcontourf(f,[-pi,pi])
%     ezcontourf('sin(sqrt(x^2+y^2))/sqrt(x^2+y^2)',[-6*pi,6*pi])
%     ezcontourf('x*exp(-x^2 - y^2)')
%     ezcontourf('-3*z/(1 + t^2 - z^2)',[-4,4],120)
%     ezcontourf('sin(u)*sin(v)',[-2*pi,2*pi])
% 
%    

function ezmesh
%MATLAB Tour Partial Function Help:  sym_con
%
% EZMESH Easy to use 3-D mesh plotter.
%    EZMESH(f) plots a graph of f(x,y) using MESH where f is a string
%    or a symbolic expression representing a mathematical expression
%    involving two symbolic variables, say 'x' and 'y'.  The function
%    f is plotted over the default domain -2*pi < x < 2*pi, -2*pi < y < 2*pi.
%    The computational grid is chosen according to the amount of
%    variation that occurs.
%  
%    EZMESH(f,DOMAIN) plots f over the specified DOMAIN instead of the
%    default DOMAIN = [-2*pi,2*pi,-2*pi,2*pi].  The DOMAIN can be the
%    4-by-1 vector [xmin,xmax,ymin,ymax] or the 2-by-1 vector [a,b] (to
%    plot over a < x < b, a < y < b).
% 
%    If f is a function of the variables u and v (rather than x and
%    y), then the domain endpoints umin, umax, vmin, and vmax are
%    sorted alphabetically.  Thus, EZMESH('u^2 - v^3',[0,1,3,6]) plots
%    u^2 - v^3 over 0 < u < 1, 3 < v < 6.
% 
%    EZMESH(x,y,z) plots the parametric surface x = x(s,t), y = y(s,t),
%    and z = z(s,t) over the square -2*pi < s < 2*pi and -2*pi < t < 2*pi.
% 
%    EZMESH(x,y,z,[smin,smax,tmin,tmax]) or EZMESH(x,y,z,[a,b]) uses the
%    specified domain.
% 
%    EZMESH(...,N) plots f over the default domain using an N-by-N grid.
%    The default value for N is 60..
% 
%    EZMESH(...,'circ') plots f over a disk centered on the domain.
% 
%    ROTATE3D always on.  To rotate the graph, click and drag with your mouse.
% 
%    Examples:
%     f = ['3*(1-x)^2*exp(-(x^2) - (y+1)^2)' ... 
%        '- 10*(x/5 - x^3 - y^5)*exp(-x^2-y^2)' ... 
%        '- 1/3*exp(-(x+1)^2 - y^2)'];
%     ezmesh(f,[-pi,pi])
%     ezmesh('x*exp(-x^2 - y^2)')
%     ezmesh('x*y','circ')
%     ezmesh('real(atan(x + i*y))')
%     ezmesh('exp(-x)*cos(t)',[-4*pi,4*pi,-2,2])
% 
%     ezmesh('s*cos(t)','s*sin(t)','t')
%     ezmesh('exp(-s)*cos(t)','exp(-s)*sin(t)','t',[0,8,0,4*pi])
%     ezmesh('(s-sin(s))*cos(t)','(1-cos(s))*sin(t)','s',[-2*pi,2*pi])
% 
%    

function ezmeshc
%MATLAB Tour Partial Function Help:  sym_con
%
% EZMESHC Easy to use combination mesh/contour plotter.
%    EZMESHC(f) plots a graph of f(x,y) using MESHC where f is a string
%    or a symbolic expression representing a mathematical expression
%    involving two symbolic variables, say 'x' and 'y'.  The function
%    f is plotted over the default domain -2*pi < x < 2*pi, -2*pi < y < 2*pi.
%    The computational grid is chosen according to the amount of
%    variation that occurs.
%  
%    EZMESHC(f,DOMAIN) plots f over the specified DOMAIN instead of the
%    default DOMAIN = [-2*pi,2*pi,-2*pi,2*pi].  The DOMAIN can be the
%    4-by-1 vector [xmin,xmax,ymin,ymax] or the 2-by-1 vector [a,b] (to
%    plot over a < x < b, a < y < b).
% 
%    If f is a function of the variables u and v (rather than x and
%    y), then the domain endpoints umin, umax, vmin, and vmax are
%    sorted alphabetically.  Thus, EZMESHC('u^2 - v^3',[0,1,3,6]) plots
%    u^2 - v^3 over 0 < u < 1, 3 < v < 6.
% 
%    EZMESHC(x,y,z) plots the parametric surface x = x(s,t), y = y(s,t),
%    and z = z(s,t) over the square -2*pi < s < 2*pi and -2*pi < t < 2*pi.
% 
%    EZMESHC(x,y,z,[smin,smax,tmin,tmax]) or EZMESHC(x,y,z,[a,b]) uses the
%    specified domain.
% 
%    EZMESHC(...,N) plots f over the default domain using an N-by-N grid.
%    The default value for N is 60.
% 
%    EZMESHC(...,'circ') plots f over a disk centered on the domain.
% 
%    ROTATE3D always on.  To rotate the graph, click and drag with your mouse.
% 
%    Examples:
%     f = ['3*(1-x)^2*exp(-(x^2) - (y+1)^2)' ... 
%        '- 10*(x/5 - x^3 - y^5)*exp(-x^2-y^2)' ... 
%        '- 1/3*exp(-(x+1)^2 - y^2)'];
%     ezmeshc(f,[-pi,pi])
%     ezmeshc('x*exp(-x^2 - y^2)')
%     ezmeshc('sin(u)*sin(v)')
%     ezmeshc('imag(atan(x + i*y))',[-2,2])
%     ezmeshc('y/(1 + x^2 + y^2)',[-5,5,-2*pi,2*pi])
% 
%     ezmeshc((s-sin(s))*cos(t),(1-cos(s))*sin(t),s,[-2*pi,2*pi])
% 
%    

function ezplot
%MATLAB Tour Partial Function Help:  sym_con
%
% EZPLOT Easy to use function plotter.
%    EZPLOT(f) plots the expression f = f(x) over the default
%    domain -2*pi < x < 2*pi.
% 
%    EZPLOT(f, [a,b]) plots f = f(x) over a < x < b
% 
%    For implicitly defined functions, f = f(x,y)
%    EZPLOT(f) plots f(x,y) = 0 over the default domain
%    -2*pi < x < 2*pi and -2*pi < x < 2*pi
%    EZPLOT(f, [xmin,xmax,ymin,ymax]) plots f(x,y) = 0 over
%    xmin < x < xmax and  ymin < y < ymax.
%    EZPLOT(f, [a,b]) plots f(x,y) = 0 over a < x < b and a < y < b.
%    If f is a function of the variables u and v (rather than x and y), then
%    the domain endpoints a, b, c, and d are sorted alphabetically. Thus,
%    EZPLOT('u^2 - v^2 - 1',[-3,2,-2,3]) plots u^2 - v^2 - 1 = 0 over
%    -3 < u < 2, -2 < v < 3.
% 
%    EZPLOT(x,y) plots the parametrically defined planar curve x = x(t)
%    and y = y(t) over the default domain 0 < t < 2*pi.
%    EZPLOT(x,y, [tmin,tmax]) plots x = x(t) and y = y(t) over
%    tmin < t < tmax.
% 
%    EZPLOT(f, [a,b], FIG), EZPLOT(f, [xmin,xmax,ymin,ymax], FIG), or
%    EZPLOT(x,y, [tmin,tmax], FIG) plots the given function over the
%    specified domain in the figure window FIG.
% 
%    Examples:
%      ezplot('cos(x)')
%      ezplot('cos(x)', [0, pi])
%      ezplot('1/y-log(y)+log(-1+y)+x - 1')
%      ezplot('x^2 - y^2 - 1')
%      ezplot('x^2 + y^2 - 1',[-1.25,1.25]); axis equal
%      ezplot('x^3 + y^3 - 5*x*y + 1/5',[-3,3])
%      ezplot('x^3 + 2*x^2 - 3*x + 5 - y^2')
%      ezplot('sin(t)','cos(t)')
%      ezplot('sin(3*t)*cos(t)','sin(3*t)*sin(t)',[0,pi])
%      ezplot('t*cos(t)','t*sin(t)',[0,4*pi])
%
% Overloaded methods
%    help sym/ezplot.m

function ezplot3
%MATLAB Tour Partial Function Help:  sym_con
%
%  EZPLOT3  Easy to use 3-d parametric curve plotter.
%    EZPLOT3(x,y,z) plots the spatial curve x = x(t), y = y(t),
%    and z = z(t) over the default domain 0 < t < 2*pi.
% 
%    EZPLOT3(x,y,z,[tmin,tmax]) plots the curve x = x(t), y = y(t),
%    and z = z(t) over tmin < t < tmax.
% 
%    EZPLOT3(x,y,z,'animate') or EZPLOT(x,y,z,[tminm,tmax],'animate')
%    produces an animated trace of the spatial curve.
%    
%    Examples
%      ezplot3('sin(t)','cos(t)','t')
%      ezplot3('sin(t)','cos(t)','t',[0,6*pi])
%      ezplot3('sin(3*t)*cos(t)','sin(3*t)*sin(t)','t',[0,12],'animate')
%      ezplot3('(4+cos(1.5*t))*cos(t)','(2+cos(1.5*t))*sin(t)', ...
%              'sin(1.5*t)',[0,4*pi])
% 
%   

function ezpolar
%MATLAB Tour Partial Function Help:  sym_con
%
%  EZPOLAR Easy to use polar coordinate plotter.
%    EZPOLAR(f) plots the polar curve rho = f(theta) over the
%    default domain 0 < theta < 2*pi.
% 
%    EZPOLAR(f,[a,b]) plots f for a < theta < b.
% 
%    Examples
%        ezpolar('1 + cos(t)')
%        ezpolar('cos(2*t)')
%        ezpolar('sin(tan(t))')
%        ezpolar('sin(3*t)')
%        ezpolar('cos(5*t)')
%        ezpolar('sin(2*t)*cos(3*t)',[0,pi])
%        ezpolar('1 + 2*sin(t/2)')
%        ezpolar('1 - 2*sin(3*t)')
%        ezpolar('sin(t)/t', [-6*pi,6*pi])
% 
%        r = '100/(100+(t-1/2*pi)^8)*(2-sin(7*t)-1/2*cos(30*t))';
%        ezpolar(r,[-pi/2,3*pi/2])
% 
%   

function ezsurf
%MATLAB Tour Partial Function Help:  sym_con
%
% EZSURF Easy to use 3-D colored surface plotter.
%    EZSURF(f) plots a graph of f(x,y) using SURF where f is a string
%    or a symbolic expression representing a mathematical function
%    involving two symbolic variables, say 'x' and 'y'.  The function
%    f is plotted over the default domain -2*pi < x < 2*pi, -2*pi < y < 2*pi.
%    The computational grid is chosen according to the amount of
%    variation that occurs.
%  
%    EZSURF(f,DOMAIN) plots f over the specified DOMAIN instead of the
%    default DOMAIN = [-2*pi,2*pi,-2*pi,2*pi].  The DOMAIN can be the
%    4-by-1 vector [xmin,xmax,ymin,ymax] or the 2-by-1 vector [a,b] (to
%    plot over a < x < b, a < y < b).
% 
%    If f is a function of the variables u and v (rather than x and
%    y), then the domain endpoints umin, umax, vmin, and vmax are
%    sorted alphabetically.  Thus, EZSURF('u^2 - v^3',[0,1,3,6]) plots
%    u^2 - v^3 over 0 < u < 1, 3 < v < 6.
% 
%    EZSURF(x,y,z) plots the parametric surface x = x(s,t), y = y(s,t),
%    and z = z(s,t) over the square -2*pi < s < 2*pi and -2*pi < t < 2*pi.
% 
%    EZSURF(x,y,z,[smin,smax,tmin,tmax]) or EZSURF(x,y,z,[a,b]) uses the
%    specified domain.
% 
%    EZSURF(...,N) plots f over the default domain using an N-by-N grid.
%    The default value for N is 60.
% 
%    EZSURF(...,'circ') plots f over a disk centered on the domain.
% 
%    ROTATE3D always on.  To rotate the graph, click and drag with your mouse.
% 
%    Examples:
%     f = ['3*(1-x)^2*exp(-(x^2) - (y+1)^2)' ... 
%        '- 10*(x/5 - x^3 - y^5)*exp(-x^2-y^2)' ... 
%        '- 1/3*exp(-(x+1)^2 - y^2)'];
%     ezsurf(f,[-pi,pi])
%     ezsurf('sin(sqrt(x^2+y^2))/sqrt(x^2+y^2)',[-6*pi,6*pi])
%     ezsurf('x*exp(-x^2 - y^2)')
%     ezsurf('x*(y^2)/(x^2 + y^4)')
%     ezsurf('x*y','circ')
%     ezsurf('real(atan(x + i*y))')
%     ezsurf('exp(-x)*cos(t)',[-4*pi,4*pi,-2,2])
% 
%     ezsurf('s*cos(t)','s*sin(t)','t')
%     ezsurf('s*cos(t)','s*sin(t)','s')
%     ezsurf('exp(-s)*cos(t)','exp(-s)*sin(t)','t',[0,8,0,4*pi])
%     ezsurf('cos(s)*cos(t)','cos(s)*sin(t)','sin(s)',[0,pi/2,0,3*pi/2])
%     ezsurf('(s-sin(s))*cos(t)','(1-cos(s))*sin(t)','s',[-2*pi,2*pi])
%     ezsurf('(1-s)*(3+cos(t))*cos(4*pi*s)', '(1-s)*(3+cos(t))*sin(4*pi*s)', ...
%               '3*s + (1 - s)*sin(t)', [0,2*pi/3,0,12] )
% 
%    

function ezsurfc
%MATLAB Tour Partial Function Help:  sym_con
%
% EZSURFC Easy to use combination surf/contour plotter.
%    EZSURFC(f) plots a graph of f(x,y) using SURFC where f is a string
%    or a symbolic expression representing a mathematical expression
%    involving two symbolic variables, say 'x' and 'y'.  The function
%    f is plotted over the default domain -2*pi < x < 2*pi, -2*pi < y < 2*pi.
%    The computational grid is chosen according to the amount of
%    variation that occurs.
%  
%    EZSURFC(f,DOMAIN) plots f over the specified DOMAIN instead of the
%    default DOMAIN = [-2*pi,2*pi,-2*pi,2*pi].  The DOMAIN can be the
%    4-by-1 vector [xmin,xmax,ymin,ymax] or the 2-by-1 vector [a,b] (to
%    plot over a < x < b, a < y < b).
% 
%    If f is a function of the variables u and v (rather than x and
%    y), then the domain endpoints umin, umax, vmin, and vmax are
%    sorted alphabetically.  Thus, EZSURFC('u^2 - v^3',[0,1,3,6]) plots
%    u^2 - v^3 over 0 < u < 1, 3 < v < 6.
% 
%    EZSURFC(x,y,z) plots the parametric surface x = x(s,t), y = y(s,t),
%    and z = z(s,t) over the square -2*pi < s < 2*pi and -2*pi < t < 2*pi.
% 
%    EZSURFC(x,y,z,[smin,smax,tmin,tmax]) or EZSURFC(x,y,z,[a,b]) uses the
%    specified domain.
% 
%    EZSURFC(...,N) plots f over the default domain using an N-by-N grid.
%    The default value for N is 60.
% 
%    EZSURFC(...,'circ') plots f over a disk centered on the domain.
% 
%    ROTATE3D always on.  To rotate the graph, click and drag with your mouse.
% 
%    Examples:
%     f = ['3*(1-x)^2*exp(-(x^2) - (y+1)^2)' ... 
%        '- 10*(x/5 - x^3 - y^5)*exp(-x^2-y^2)' ... 
%        '- 1/3*exp(-(x+1)^2 - y^2)'];
%     ezsurfc(f,[-pi,pi])
%     ezsurfc('x*exp(-x^2 - y^2)')
%     ezsurfc('sin(u)*sin(v)')
%     ezsurfc('imag(atan(x + i*y))',[-2,2])
%     ezsurfc('y/(1 + x^2 + y^2)',[-5,5,-2*pi,2*pi])
% 
%     ezsurfc('(s-sin(s))*cos(t)','(1-cos(s))*sin(t)','s',[-2*pi,2*pi])
% 
%    

function funtool
%MATLAB Tour Partial Function Help:  sym_con
%
% FUNTOOL A function calculator.
%    FUNTOOL is an interactive graphing calculator that manipulates
%    functions of a single variable.  At any time, there are two functions
%    displayed, f(x) and g(x).  The result of most operations replaces f(x).
% 
%    The controls labeled 'f = ' and 'g = ' are editable text that may
%    be changed at any time to install a new function.  The control
%    labeled 'x = ' may be changed to specify a new domain.  The control
%    labeled 'a = ' may be changed to specify a new value of a parameter.
% 
%    The top row of control buttons are unary function operators that
%    involve only f(x).  These operators are:
%       df/dx     - Symbolically differentiate f(x).
%       int f     - Symbolically integrate f(x).
%       simple f  - Simplify the symbolic expression, if possible.
%       num f     - Extract the numerator of a rational expression.
%       den f     - Extract the denominator of a rational expression.
%       1/f       - Replace f(x) by 1/f(x).
%       finv      - Replace f(x) by its inverse function.
% 
%    The operators int(f) and finv may fail if the corresponding symbolic
%    expressions do not exist in closed form.
% 
%    The second row of buttons translate and scale f(x) by the parameter 'a'.
%    The operations are:
%       f + a    - Replace f(x) by f(x) + a.
%       f - a    - Replace f(x) by f(x) - a.
%       f * a    - Replace f(x) by f(x) * a.
%       f / a    - Replace f(x) by f(x) / a.
%       f ^ a    - Replace f(x) by f(x) ^ a.
%       f(x+a)   - Replace f(x) by f(x + a).
%       f(x*a)   - Replace f(x) by f(x * a).
% 
%    The third row of buttons are binary function operators that
%    operate on both f(x) and g(x).  The operations are:
%       f + g  - Replace f(x) by f(x) + g(x).
%       f - g  - Replace f(x) by f(x) - g(x).
%       f * g  - Replace f(x) by f(x) * g(x).
%       f / g  - Replace f(x) by f(x) / g(x).
%       f(g)   - Replace f(x) by f(g(x)).
%       g = f  - Replace g(x) by f(x).
%       swap   - Interchange f(x) and g(x).
% 
%    The first three buttons in the fourth row manage a list of functions.
%    The Insert button places the current active function in the list.
%    The Cycle button rotates the function list.
%    The Delete button removes the active function from the list.  
%    The list of functions is named fxlist.  A default fxlist containing 
%            several interesting functions is provided.
% 
%    The Reset button sets f, g, x, a and fxlist to their initial values.
%    The Help button prints this help text.  
% 
%    The Demo button poses the following challenge: Can you generate the
%    function sin(x) without touching the keyboard, using just the mouse?
%    The demo does it with a reset and then nine clicks.  If you can do
%    it with fewer clicks, please send e-mail to moler@mathworks.com.
% 
%    The Close button closes all three windows.
% 
%    

function taylortool
%MATLAB Tour Partial Function Help:  sym_con
%
% TAYLORTOOL A Taylor series calculator.
% 
%    TAYLORTOOL is an interactive Taylor series calculator that 
%    graphs a function f against the Nth partial sum of its
%    Taylor series over [-2*pi,2*pi]. The default values for f
%    and N are x*cos(x) and 7, respectively.
% 
%    TAYLORTOOL(f) Graphs the function f versus the Nth
%    partial sum of the Taylor series for f over [-2*pi,2*pi].
%    The default value for N is 7.
%    Note that f must be a quoted string.
% 
%    Example:  taylortool('sin(tan(x)) - tan(sin(x))')
% 
%    

function symintro
%MATLAB Tour Partial Function Help:  sym_con
%
% SYMINTRO Introduction to the Symbolic Math Toolbox.

function symcalcdemo
%MATLAB Tour Partial Function Help:  sym_con
%
%  This is a slideshow file for use with playshow.m and makeshow.m
%  Too see it run, type 'playshow symcalcdemo', 

function symlindemo
%MATLAB Tour Partial Function Help:  sym_con
%
% SYMLINDEMO Demonstrate Symbolic Linear Algebra.

function symvpademo
%MATLAB Tour Partial Function Help:  sym_con
%
% SYMVPADEMO Demonstrate Variable Precision Arithmetic

function symrotdemo
%MATLAB Tour Partial Function Help:  sym_con
%
% SYMROTDEMO Study plane rotations.

function symeqndemo
%MATLAB Tour Partial Function Help:  sym_con
%
% SYMEQNDEMO Demonstrate symbolic equation solving.

function maple
%MATLAB Tour Partial Function Help:  sym_con
%
% MAPLE String access to the Maple kernel.
%    MAPLE(STATEMENT) sends STATEMENT to the Maple kernel. 
%    STATEMENT is a string representing a syntactically valid Maple 
%    command. A semicolon for the Maple syntax is appended to STATEMENT
%    if necessary. The result is a string in Maple syntax.
% 
%    MAPLE('function',ARG1,ARG2,..,) accepts the quoted name of any Maple
%    function and its corresponding arguments. The Maple statement is formed
%    as: function(arg1, arg2, arg3, ...), that is, commas are added between
%    the arguments. All of the input arguments must be strings that are
%    syntactically valid in Maple. The result is returned as a string in the 
%    Maple syntax.  To convert the result from a Maple string to a symbolic
%    object, use SYM.
% 
%    [RESULT,STATUS] = MAPLE(...) returns the warning/error status.
%    When the statement execution is successful, RESULT is the result
%    and STATUS is 0. If the execution fails, RESULT is the corresponding 
%    warning/error message, and STATUS is a positive integer.
% 
%    The statements
%       maple traceon  or  maple trace on
%    cause subsequent Maple commands and results to be printed.
%    The statements
%       maple traceoff  or  maple trace off
%    turn off this facility.
%    The statements
%       maple clear  or  maple restart
%    clear off the Maple workspace and reinitialize the Maple kernel.
% 
%    MAPLE is not available for general use in the Student Edition.
% 
%    

function mfun
%MATLAB Tour Partial Function Help:  sym_con
%
% MFUN   Numeric evaluation of a Maple function.
%    MFUN('fun',p1,p2,...,pk), where 'fun' is the name of a Maple 
%    function and the p's are numeric quantities corresponding to fun's 
%    parameters.  The last parameter specified may be a matrix. All other 
%    parameters must be the type specified by the Maple function.
%    MFUN numerically evaluates 'fun' with the specified parameters
%    and returns MATLAB doubles. Any singularity in 'fun' is returned 
%    as NaN.
% 
%    Example:
%       x = 0:0.1:5.0;
%       y = mfun('FresnelC',x)
% 
%    MFUN is not available in the Student Edition.
% 
%    

function mfunlist
%MATLAB Tour Partial Function Help:  sym_con
%
% MFUNLIST Special functions for MFUN.
%    The following special functions are listed in alphabetical order
%    according to the third column. n denotes an integer argument, 
%    x denotes a real argument, and z denotes a complex argument. For 
%    more detailed descriptions of the functions, including any 
%    argument restrictions, see the Reference Manual, or use MHELP.
% 
% bernoulli      n       Bernoulli Numbers
% bernoulli      n,z     Bernoulli Polynomials
% BesselI        x1,x    Bessel Function of the First Kind
% BesselJ        x1,x    Bessel Function of the First Kind
% BesselK        x1,x    Bessel Function of the Second Kind
% BesselY        x1,x    Bessel Function of the Second Kind
% Beta           z1,z2   Beta Function
% binomial       x1,x2   Binomial Coefficients
% LegendreKc     x       Complete Elliptic Integral of First Kind
% LegendreEc     x       Complete Elliptic Integral of Second Kind
% LegendrePic    x1,x    Complete Elliptic Integral of Third Kind
% LegendreKc1    x       LegendreKc using Complementary Modulus
% LegendreEc1    x       LegendreEc using Complementary Modulus
% LegendrePic1   x1,x    LegendrePic using Complementary Modulus
% erfc           z       Complementary Error Function
% erfc           n,z     Complementary Error Function's Iterated Integrals
% Ci             z       Cosine Integral
% dawson         x       Dawson's Integral
% Psi            z       Digamma Function
% dilog          x       Dilogarithm Integral
% erf            z       Error Function 
% euler          n       Euler Numbers
% euler          n,z     Euler Polynomials
% Ei             x       Exponential Integral
% Ei             n,z     Exponential Integral
% FresnelC       x       Fresnel Cosine Integral 
% FresnelS       x       Fresnel Sine Integral 
% GAMMA          z       Gamma Function 
% harmonic       n       Harmonic Function
% Chi            z       Hyperbolic Cosine Integral
% Shi            z       Hyperbolic Sine Integral
% hypergeom      X1,X2   (Generalized) Hypergeometric Function
% LegendreF      x,x1    Incomplete Elliptic Integral of First Kind
% LegendreE      x,x1    Incomplete Elliptic Integral of Second Kind
% LegendrePi     x,x2,x1 Incomplete Elliptic Integral of Third Kind
% GAMMA          z1,z2   Incomplete Gamma Function
% W              z       Lambert's W Function
% W              n,z     Lambert's W Function
% lnGAMMA        z       Logarithm of the Gamma function
% Li             x       Logarithmic Integral
% Psi            n,z     Polygamma Function
% Ssi            z       Shifted Sine Integral
% Si             z       Sine Integral
% Zeta           z       (Riemann) Zeta Function
% Zeta           n,z     (Riemann) Zeta Function
% Zeta           n,z,x   (Riemann) Zeta Function
% 
%        Orthogonal Polynomials (Extended Symbolic Math Toolbox only)
% T      n,x             Chebyshev of the First Kind
% U      n,x             Chebyshev of the Second Kind
% G      n,x1,x          Gegenbauer
% H      n,x             Hermite
% P      n,x1,x2,x       Jacobi
% L      n,x             Laguerre
% L      n,x1,x          Generalized Laguerre
% P      n,x             Legendre
% 
%    

function mhelp
%MATLAB Tour Partial Function Help:  sym_con
%
% MHELP  Maple help.
%    MHELP topic prints Maple's help text for the topic.
%    MHELP('topic') does the same thing.
% 
%    MHELP is not available in the Student Edition.
% 
%    Example: 
%       mhelp gcd 

function procread
%MATLAB Tour Partial Function Help:  sym_con
%
% PROCREAD Install a Maple procedure.
%    PROCREAD(FILENAME) reads the specified file, which contains 
%    the source text for a Maple procedure. PROCREAD deletes any
%    comments and newline characters, and then sends the resulting 
%    string to Maple. The Extended Symbolic Toolbox is required to
%    use PROCREAD.
% 
%    Example:
%       Suppose the file "check.src" contains the following
%       source text for a Maple procedure.
% 
%          check := proc(A)
%             #   check(A) computes A*inverse(A)
%             local X;
%             X := inverse(A):
%             evalm(A &* X);
%          end;
% 
%       Then the statement
% 
%          procread('check.src')
% 
%       installs the procedure.  It can be accessed with 
% 
%          maple('check',magic(3))
% 
%       or
% 
%          maple('check',vpa(magic(3)))
% 
%    

